@@ -2,6 +2,7 @@
 
 $LANG = array(
 
+'L_ID' 												=> '#',
 'L_MENU'											=> 'Menü',
 'L_UNKNOWN_ERROR'									=> 'Unbekannter Fehler',
 'L_CONFIRM_DELETE'									=> 'Löschen bestätigen?',
@@ -14,6 +15,11 @@ $LANG = array(
 'L_DELETE'											=> 'Löschen',
 'L_DELETE_FILE' 				    				=> 'Datei löschen',
 'L_DELETE_FOLDER'				   					=> 'Verzeichnis löschen',
+'L_DELETE_SUCCESSFUL'								=> 'Erfolgreiche Löschung',
+'L_DELETE_FILE_ERR'									=> 'Fehler beim Löschen der Datei',
+'L_RENAME_FILE_SUCCESSFUL'							=> 'Datei umbenannt erfolgreich',
+'L_RENAME_FILE_ERR'									=> 'Fehler beim Verarbeiten der Datei',
+'L_RENAME_FILE'										=> 'Datei umbenennen',
 'L_THUMBNAIL'										=> 'Vorschaubild (optional)',
 'L_THUMBNAIL_SELECTION'								=> 'Bild auswählen',
 'L_THUMBNAIL_TITLE'									=> 'Bildtitel (optional)',
@@ -128,6 +134,7 @@ $LANG = array(
 'L_SUBMIT_BUTTON'									=> 'Anmelden',
 'L_ERR_WRONG_PASSWORD'								=> 'Benutzername und/oder Passwort sind falsch',
 'L_POWERED_BY'										=> 'Generiert von <a href="http://www.pluxml.org">PluXml</a>',
+'L_ERR_MAXLOGIN'									=> 'Zu viele fehlgeschlagene Anmeldung <br /> Wiederholen Sie in% s Minuten',
 
 'L_CAT_TITLE'										=> 'Kategorien erstellen/ändern',
 'L_CAT_LIST_ID'										=> 'ID',
@@ -222,14 +229,14 @@ $LANG = array(
 'L_ARTICLE_LIST_ACTION'								=> 'Aktion',
 'L_CATEGORY_HOME'									=> 'Homepage',
 'L_CATEGORY_DRAFT'									=> 'Entwurf',
-'L_ARTICLE_VIEW'									=> 'Ansehen',
 'L_ARTICLE_VIEW_TITLE'								=> 'Den Artikel auf der Website ansehen',
 'L_ARTICLE_EDIT'									=> 'editieren',
 'L_ARTICLE_EDIT_TITLE'								=> 'Diesen Artikel bearbeiten',
 'L_NEW_COMMENTS_TITLE'								=> 'Wartende Kommentare',
 'L_VALIDATED_COMMENTS_TITLE'						=> 'Publizierte Kommentare',
 'L_NO_ARTICLE'										=> 'Kein(e) Artikel',
-'L_ARTICLES_SEARCH_BUTTON'							=> 'Suche',
+'L_SEARCH'											=> 'Suche',
+'L_SEARCH_PLACEHOLDER'								=> 'benutzernamen oder titel',
 'L_ARTICLES_ALL_CATEGORIES'							=> 'Alle Kategorien ...',
 'L_ALL'												=> 'Alle',
 'L_ALL_PUBLISHED'									=> 'Veröffentlicht',
@@ -247,6 +254,7 @@ $LANG = array(
 'L_MEDIAS_CREATE_FOLDER'							=> 'Ordner erstellen',
 'L_MEDIAS_SUBMIT_FILE'								=> 'Abschicken',
 'L_MEDIAS_MAX_UPOLAD_FILE'							=> 'Maximale Größe der Datei',
+'L_MEDIAS_MAX_POST_SIZE'							=> 'Maximale Datengröße',
 'L_MEDIAS_DIRECTORY'								=> 'Ort',
 'L_MEDIAS_FOLDER'									=> 'Datei',
 'L_MEDIAS_NEW_FOLDER'								=> 'Neuer Ordner',
@@ -267,9 +275,15 @@ $LANG = array(
 'L_MEDIAS_ALIGN_CENTER'								=> 'Center',
 'L_MEDIAS_ALIGN_RIGHT'								=> 'Rechts',
 'L_MEDIAS_RECREATE_THUMB'							=> 'Miniaturansicht neu erstellen',
+'L_MEDIAS_LINK_COPYCLP'                             => 'Link kopieren kopieren',
+'L_MEDIAS_LINK_COPYCLP_ERR'                         => 'Können Sie den Link in die Zwischenablage zu kopieren',
+'L_MEDIAS_LINK_COPYCLP_DONE'                        => 'Link kopiert',
+'L_MEDIAS_NEW_NAME'									=> 'Neuer Name',
+'L_MEDIAS_RENAME'									=> 'Umbenennen',
 'L_SORT_ASCENDING_DATE'								=> 'Datum aufsteigend',
 'L_SORT_DESCENDING_DATE'							=> 'Datum absteigend',
 'L_SORT_ALPHABETICAL'								=> 'alphabetisch',
+'L_SORT_RANDOM'										=> 'aleatorischen',
 'L_OK'												=> 'Ok',
 'L_YES'												=> 'Ja',
 'L_NO'												=> 'Nein',
@@ -282,6 +296,7 @@ $LANG = array(
 'L_CONFIG_VIEW_SORT'								=> 'Artikelsortierung',
 'L_CONFIG_VIEW_BYPAGE'								=> 'Angezeigte Artikel pro Seite',
 'L_CONFIG_VIEW_BYPAGE_ARCHIVES'						=> 'Angezeigte Artikel pro Seite (Archiv)',
+'L_CONFIG_VIEW_BYPAGE_TAGS'							=> 'Angezeigte Artikel pro Seite in Tags',
 'L_CONFIG_VIEW_BYPAGE_ADMIN'						=> 'Angezeigte Artikel pro Seite (Admin)',
 'L_CONFIG_VIEW_SORT_COMS'							=> 'Kommentarsortierung',
 'L_CONFIG_VIEW_BYPAGE_ADMIN_COMS'					=> 'Angezeigte Kommentare pro Seite (Admin)',
@@ -370,6 +385,8 @@ $LANG = array(
 'L_PLUGINS_DELETE_SUCCESSFUL'						=> 'Löschen war erfolgreich',
 'L_PLUGINS_CONFIG'									=> 'Konfiguration',
 'L_PLUGINS_CONFIG_TITLE'							=> 'Pluginkonfiguration',
+'L_PLUGINS_HELP'									=> 'Hilfe',
+'L_PLUGINS_HELP_TITLE'								=> 'Siehe die Benutzung von Plugins',
 'L_PLUGINS_REQUIREMENTS'							=> 'Voraussetzungen',
 'L_PLUGINS_REQUIREMENTS_HELP'						=> 'Vorausgesetzte Plugins (installiert und aktiviert), damit dieses Plugin verwendet werden kann',
 'L_PLUGINS_REQUIREMENTS_NONE'						=> 'Kein',
@@ -423,7 +440,7 @@ $LANG = array(
 'L_PROFIL_MODERATOR'								=> 'Moderator',
 'L_PROFIL_EDITOR'									=> 'Redakteur',
 'L_PROFIL_WRITER'									=> 'Autor',
-'L_ADMIN'											=> '- Admin',
+'L_ADMIN'											=> 'Admin',
 'L_LOGIN'											=> 'Angemeldet als ',
 'L_ADMIN_LOGOUT'									=> 'Abmelden',
 'L_ADMIN_LOGOUT_TITLE'								=> 'Administration beenden',
@@ -447,7 +464,7 @@ $LANG = array(
 'L_MENU_CONFIG'										=> 'Konfiguration',
 'L_MENU_PROFIL_TITLE'								=> 'Mein Benutzerprofil verwalten',
 'L_MENU_PROFIL'										=> 'Mein Profil',
-'L_WARNING_INSTALLATION_FILE'						=> 'Die Datei install.php existiert noch im Grundverzeichnis von PluXml.<br />Sie sollten diese aus Sicherheitsgründen löschen.',
+'L_WARNING_INSTALLATION_FILE'						=> 'Die Datei install.php existiert noch im Grundverzeichnis von PluXml.<br />Sie sollten diese aus Sicherheitsgründen <a class="lnkdelete" href="?del=install">löschen</a>.',
 'L_USER_UNKNOWN'									=> 'Unbekannter Benutzer',
 'L_USER_LANG'										=> 'Spracher des Admins',
 'L_USER_MAIL'										=> 'E-Mail-Adresse',
@@ -473,7 +490,8 @@ $LANG = array(
 'L_HELP'											=> 'Hilfe',
 'L_HELP_TITLE'										=> 'Siehe Hilfe',
 'L_BACK_TO_THEMES'									=> 'Zurück Hilfe',
+'L_CONFIG_THEME_UPDATE'								=> 'Theme ändern',
 'L_ERR_INVALID_DATE_CREATION'						=> 'Ungültige Erstellungsdatum',
-'L_ERR_INVALID_DATE_UPDATE'							=> 'Datum ungültig aktualisiert',	
+'L_ERR_INVALID_DATE_UPDATE'							=> 'Datum ungültig aktualisiert',
 );
 ?>
\ No newline at end of file
