@@ -2,6 +2,7 @@
 
 $LANG = array(
 
+'L_ID' 														=> '#',
 'L_MENU'													=> 'Menu',
 'L_UNKNOWN_ERROR'											=> 'Unknown error',
 'L_CONFIRM_DELETE'											=> 'Confirm the deletion?',
@@ -14,6 +15,11 @@ $LANG = array(
 'L_DELETE'													=> 'Delete',
 'L_DELETE_FILE' 				    						=> 'Delete file',
 'L_DELETE_FOLDER'				   							=> 'Delete folder',
+'L_DELETE_SUCCESSFUL'										=> 'Successfully deleted',
+'L_DELETE_FILE_ERR'											=> 'Error while deleting file',
+'L_RENAME_FILE_SUCCESSFUL'									=> 'Successfully renamed file',
+'L_RENAME_FILE_ERR'											=> 'Error while processing file',
+'L_RENAME_FILE'												=> 'Rename file',
 'L_THUMBNAIL'												=> 'Thumbnail (optional)',
 'L_THUMBNAIL_SELECTION'										=> 'Select image',
 'L_THUMBNAIL_TITLE'											=> 'Image Title (optional)',
@@ -128,6 +134,7 @@ $LANG = array(
 'L_SUBMIT_BUTTON'											=> 'Submit',
 'L_ERR_WRONG_PASSWORD'										=> 'Incorrect login or password',
 'L_POWERED_BY'												=> 'Powered by <a href="http://www.pluxml.org">PluXml</a>',
+'L_ERR_MAXLOGIN'											=> 'Too many failed login<br />Retry in % s minutes',
 'L_CAT_TITLE'												=> 'Category Manager',
 'L_CAT_LIST_ID'												=> 'ID',
 'L_CAT_LIST_ACTIVE'											=> 'Active',
@@ -144,6 +151,7 @@ $LANG = array(
 'L_SORT_ASCENDING_DATE'										=> 'ascending date',
 'L_SORT_DESCENDING_DATE'									=> 'descending date',
 'L_SORT_ALPHABETICAL'										=> 'alphabetical',
+'L_SORT_RANDOM'												=> 'random',
 'L_OK'														=> 'Ok',
 'L_YES'														=> 'Yes',
 'L_NO'														=> 'No',
@@ -229,14 +237,14 @@ $LANG = array(
 'L_ARTICLE_LIST_ACTION'										=> 'Action',
 'L_CATEGORY_HOME'											=> 'Home',
 'L_CATEGORY_DRAFT'											=> 'Draft',
-'L_ARTICLE_VIEW'											=> 'View',
 'L_ARTICLE_VIEW_TITLE'										=> 'View this article online',
 'L_ARTICLE_EDIT'											=> 'Edit',
 'L_ARTICLE_EDIT_TITLE'										=> 'Edit this article',
 'L_NEW_COMMENTS_TITLE'										=> 'Comments awaiting moderation',
 'L_VALIDATED_COMMENTS_TITLE'								=> 'Published comments',
 'L_NO_ARTICLE'												=> 'No article',
-'L_ARTICLES_SEARCH_BUTTON'									=> 'Search',
+'L_SEARCH'													=> 'Search',
+'L_SEARCH_PLACEHOLDER'										=> 'article id or title',
 'L_ARTICLES_ALL_CATEGORIES'									=> 'All Categories ...',
 'L_ALL'														=> 'All',
 'L_ALL_PUBLISHED'											=> 'Published',
@@ -254,6 +262,7 @@ $LANG = array(
 'L_MEDIAS_CREATE_FOLDER'									=> 'Create folder',
 'L_MEDIAS_SUBMIT_FILE'										=> 'Send',
 'L_MEDIAS_MAX_UPOLAD_FILE'									=> 'Maximum file size',
+'L_MEDIAS_MAX_POST_SIZE'									=> 'Maximum data size',
 'L_MEDIAS_DIRECTORY'										=> 'Location',
 'L_MEDIAS_FOLDER'											=> 'File',
 'L_MEDIAS_NEW_FOLDER'										=> 'New Folder',
@@ -274,6 +283,11 @@ $LANG = array(
 'L_MEDIAS_ALIGN_CENTER'										=> 'Center',
 'L_MEDIAS_ALIGN_RIGHT'										=> 'Right',
 'L_MEDIAS_RECREATE_THUMB'									=> 'Recreate thumbnail',
+'L_MEDIAS_LINK_COPYCLP'                                     => 'Copy link to clipboard',
+'L_MEDIAS_LINK_COPYCLP_ERR'                                 => 'Unable to copy link to clipboard',
+'L_MEDIAS_LINK_COPYCLP_DONE'                                => 'Copied link',
+'L_MEDIAS_NEW_NAME'											=> 'New name',	
+'L_MEDIAS_RENAME'											=> 'Rename',
 'L_CONFIG_VIEW_FIELD'										=> 'Display preferences',
 'L_CONFIG_VIEW_SKIN_SELECT'									=> 'Skin',
 'L_CONFIG_VIEW_FILES_EDIT_TITLE'							=> 'Edit theme files',
@@ -281,6 +295,7 @@ $LANG = array(
 'L_CONFIG_VIEW_SORT'										=> 'Sorting articles',
 'L_CONFIG_VIEW_BYPAGE'										=> 'Articles per page',
 'L_CONFIG_VIEW_BYPAGE_ARCHIVES'								=> 'Articles per page in archives',
+'L_CONFIG_VIEW_BYPAGE_TAGS'									=> 'Articles per page in tags',
 'L_CONFIG_VIEW_BYPAGE_ADMIN'								=> 'Articles per page in administration',
 'L_CONFIG_VIEW_SORT_COMS'									=> 'Sorting comments',
 'L_CONFIG_VIEW_BYPAGE_ADMIN_COMS'							=> 'Comments per page in administraton',
@@ -339,7 +354,7 @@ $LANG = array(
 'L_PLUXML_CHECK_VERSION'									=> 'Checking version number on the official PluXml.org site',
 'L_PLUXML_UPDATE_UNAVAILABLE'								=> 'Can\'t check for updates as long as \'allow_url_fopen\' is disabled on this system',
 'L_PLUXML_UPDATE_ERR'										=> 'Update check failed for an unknown reason',
-'L_PLUXML_UPTODATE'											=> 'You are using PluXml\'s last version',
+'L_PLUXML_UPTODATE'											=> 'You are using PluXml\'s lastest version',
 'L_PLUXML_UPDATE_AVAILABLE'									=> 'A new PluXml version is available ! You can download it from',
 'L_CONFIG_USERS_TITLE'										=> 'Manage users',
 'L_CONFIG_USER'												=> 'User',
@@ -369,6 +384,8 @@ $LANG = array(
 'L_PLUGINS_DELETE_SUCCESSFUL'								=> 'Successfull deletion',
 'L_PLUGINS_CONFIG'											=> 'Configuration',
 'L_PLUGINS_CONFIG_TITLE'									=> 'Plugin\'s configuration',
+'L_PLUGINS_HELP'											=> 'Help',
+'L_PLUGINS_HELP_TITLE'										=> 'See how to use the plugin',
 'L_PLUGINS_REQUIREMENTS'									=> 'Requirements',
 'L_PLUGINS_REQUIREMENTS_HELP'								=> 'Available and active plugins to activate this one',
 'L_PLUGINS_REQUIREMENTS_NONE'								=> 'None',
@@ -382,7 +399,7 @@ $LANG = array(
 'L_PROFIL'													=> 'Profile',
 'L_PROFIL_LOGIN'											=> 'Login',
 'L_PROFIL_USER'												=> 'Username',
-'L_PROFIL_MAIL'												=> 'Email address',
+'L_PROFIL_MAIL'												=> 'E-mail adress',
 'L_PROFIL_ADMIN_LANG'										=> 'Language for administration',
 'L_PROFIL_INFOS'											=> 'Information',
 'L_PROFIL_UPDATE'											=> 'Save profile',
@@ -422,7 +439,7 @@ $LANG = array(
 'L_PROFIL_MODERATOR'										=> 'Moderator',
 'L_PROFIL_EDITOR'											=> 'Editor',
 'L_PROFIL_WRITER'											=> 'Writer',
-'L_ADMIN'													=> '- Administration',
+'L_ADMIN'													=> 'Administration',
 'L_LOGIN'													=> 'Connected as',
 'L_ADMIN_LOGOUT'											=> 'Disconnect',
 'L_ADMIN_LOGOUT_TITLE'										=> 'Leave administrator\'s session',
@@ -446,10 +463,10 @@ $LANG = array(
 'L_MENU_CONFIG'												=> 'Parameters',
 'L_MENU_PROFIL_TITLE'										=> 'Manage your user profiles',
 'L_MENU_PROFIL'												=> 'Profile',
-'L_WARNING_INSTALLATION_FILE'								=> 'install.php file can still be found at your PluXml root.<br />For security reasons, it is strongly recommended to delete it.',
+'L_WARNING_INSTALLATION_FILE'								=> 'install.php file can still be found at your PluXml root.<br />For security reasons, it is strongly recommended to <a class="lnkdelete" href="?del=install">delete</a> it.',
 'L_USER_UNKNOWN'											=> 'Unknown user',
 'L_USER_LANG'												=> 'Language used in administration',
-'L_USER_MAIL'												=> 'Email adress',
+'L_USER_MAIL'												=> 'E-mail adress',
 'L_USER_INFOS'												=> 'Information',
 'L_USER_UPDATE'												=> 'Update this user',
 'L_USER_PAGE_TITLE'											=> 'Edit user options',
@@ -472,6 +489,7 @@ $LANG = array(
 'L_HELP'													=> 'Help',
 'L_HELP_TITLE'												=> 'See help',
 'L_BACK_TO_THEMES'											=> 'Back to themes',
+'L_CONFIG_THEME_UPDATE'										=> 'Change Theme',
 'L_ERR_INVALID_DATE_CREATION'								=> 'Invalid creation date',
 'L_ERR_INVALID_DATE_UPDATE'									=> 'Invalid date updated',
 );
