@@ -2,6 +2,7 @@
 
 $LANG = array(
 
+'L_ID' 								=> 'N°',
 'L_MENU'							=> 'Menu',
 'L_UNKNOWN_ERROR'					=> 'Erreur inconnue',
 'L_CONFIRM_DELETE'					=> 'Confirmer la suppression ?',
@@ -16,6 +17,11 @@ $LANG = array(
 'L_DELETE' 						    => 'Supprimer',
 'L_DELETE_FILE' 				    => 'Supprimer fichier',
 'L_DELETE_FOLDER'				    => 'Supprimer dossier',
+'L_DELETE_SUCCESSFUL'				=> 'Suppression effectuée avec succès',
+'L_DELETE_FILE_ERR'					=> 'Erreur pendant le suppression du fichier',
+'L_RENAME_FILE_SUCCESSFUL'			=> 'Fichier renommé avec succès',
+'L_RENAME_FILE_ERR'					=> 'Erreur pendant le traitement du fichier',
+'L_RENAME_FILE'						=> 'Renommer fichier',
 
 'L_THUMBNAIL'						=> 'Image d\'accroche (facultatif)',
 'L_THUMBNAIL_SELECTION'				=> 'Sélectionner une image',
@@ -23,7 +29,7 @@ $LANG = array(
 'L_THUMBNAIL_ALT'					=> 'Texte alternatif de l\'image (facultatif)',
 
 'L_ERR_INVALID_DATE_CREATION'		=> 'Date de création invalide',
-'L_ERR_INVALID_DATE_UPDATE'			=> 'Date de mise à jour invalide',	
+'L_ERR_INVALID_DATE_UPDATE'			=> 'Date de mise à jour invalide',
 
 # class.plx.admin.php
 
@@ -146,12 +152,14 @@ $LANG = array(
 'L_SUBMIT_BUTTON'					=> 'Valider',
 'L_ERR_WRONG_PASSWORD' 				=> 'Login et/ou mot de passe incorrect',
 'L_POWERED_BY'						=> 'Généré par <a href="http://www.pluxml.org">PluXml</a>',
+'L_ERR_MAXLOGIN'					=> 'Nombre de tentative atteint<br />Réessayez dans %s minutes',
 
 #
 
 'L_SORT_ASCENDING_DATE'				=> 'date croissante',
 'L_SORT_DESCENDING_DATE'			=> 'date décroissante',
 'L_SORT_ALPHABETICAL'				=> 'alphabétique',
+'L_SORT_RANDOM'						=> 'aléatoire',
 'L_YES' 							=> 'Oui',
 'L_NO' 								=> 'Non',
 'L_OK'								=> 'Ok',
@@ -261,7 +269,8 @@ $LANG = array(
 
 # index.php
 
-'L_ARTICLES_SEARCH_BUTTON'			=> 'Rechercher',
+'L_SEARCH'							=> 'Rechercher',
+'L_SEARCH_PLACEHOLDER'				=> 'Identifiant ou titre',
 'L_ARTICLES_ALL_CATEGORIES'			=> 'Toutes les catégories...',
 'L_ALL'								=> 'Tous',
 'L_ALL_PUBLISHED'					=> 'Publiés',
@@ -280,7 +289,6 @@ $LANG = array(
 'L_ARTICLE_LIST_ACTION'				=> 'Action',
 'L_CATEGORY_HOME'					=> 'Page d\'accueil',
 'L_CATEGORY_DRAFT'					=> 'Brouillon',
-'L_ARTICLE_VIEW'					=> 'Visualiser',
 'L_ARTICLE_VIEW_TITLE'				=> 'Visualiser cet article sur le site',
 'L_ARTICLE_EDIT'					=> 'Éditer',
 'L_ARTICLE_EDIT_TITLE'				=> 'Éditer cet article',
@@ -294,7 +302,8 @@ $LANG = array(
 'L_MEDIAS_TITLE'					=> 'Gestion des médias',
 'L_MEDIAS_DIRECTORY' 				=> 'Emplacement',
 'L_MEDIAS_BACK'						=> 'Retour à la liste des médias',
-'L_MEDIAS_MAX_UPOLAD_FILE'			=> 'Taille maxi des fichiers',
+'L_MEDIAS_MAX_UPOLAD_FILE'			=> 'Taille maxi par fichier',
+'L_MEDIAS_MAX_POST_SIZE'			=> 'Taille maxi des données',
 'L_MEDIAS_SUBMIT_FILE'				=> 'Envoyer',
 'L_MEDIAS_IMAGES'					=> 'Images',
 'L_MEDIAS_DOCUMENTS'				=> 'Documents',
@@ -322,6 +331,11 @@ $LANG = array(
 'L_MEDIAS_ALIGN_CENTER'				=> 'Centre',
 'L_MEDIAS_ALIGN_RIGHT'				=> 'Droite',
 'L_MEDIAS_RECREATE_THUMB'			=> 'Recréer miniatures',
+'L_MEDIAS_LINK_COPYCLP'             => 'Copier le lien dans le presse-papier',
+'L_MEDIAS_LINK_COPYCLP_ERR'         => 'Impossible de copier le lien dans le presse-papier',
+'L_MEDIAS_LINK_COPYCLP_DONE'        => 'Lien copié',
+'L_MEDIAS_NEW_NAME'					=> 'Nouveau nom',
+'L_MEDIAS_RENAME'					=> 'Renommer',
 
 # parametres_affichage.php
 
@@ -332,6 +346,7 @@ $LANG = array(
 'L_CONFIG_VIEW_SORT'				=> 'Tri des articles',
 'L_CONFIG_VIEW_BYPAGE'				=> 'Nombre d\'articles affichés par page',
 'L_CONFIG_VIEW_BYPAGE_ARCHIVES'		=> 'Nombre d\'articles affichés par page dans les archives',
+'L_CONFIG_VIEW_BYPAGE_TAGS'			=> 'Nombre d\'articles affichés par page dans les mots clés',
 'L_CONFIG_VIEW_BYPAGE_ADMIN'		=> 'Nombre d\'articles affichés par page dans l\'administration',
 'L_CONFIG_VIEW_SORT_COMS'			=> 'Tri des commentaires',
 'L_CONFIG_VIEW_BYPAGE_ADMIN_COMS'	=> 'Nombre de commentaires affichés par page dans l\'administration',
@@ -416,7 +431,6 @@ $LANG = array(
 'L_CONFIG_USERS_UPDATE'				=> 'Modifier la liste des utilisateurs',
 'L_ERR_LOGIN_ALREADY_EXISTS'		=> 'Identifiant de connexion déjà utilisé',
 'L_ERR_USERNAME_ALREADY_EXISTS'		=> 'Nom d\'utilisateur déjà utilisé',
-'L_CONFIG_USERS_DELETE_CONFIRM'		=> 'Supprimer les utilisateurs sélectionnés ?',
 
 # parametre_plugins.php
 
@@ -458,7 +472,7 @@ $LANG = array(
 'L_PROFIL'							=> 'Profil',
 'L_PROFIL_LOGIN'					=> 'Identifiant de connexion',
 'L_PROFIL_USER'						=> 'Nom d\'utilisateur',
-'L_PROFIL_MAIL'						=> 'Adresse e-mail',
+'L_PROFIL_MAIL'						=> 'Adresse email',
 'L_PROFIL_ADMIN_LANG'				=> 'Langue utilisée dans l\'administration',
 'L_PROFIL_INFOS'					=> 'Informations',
 'L_PROFIL_UPDATE'					=> 'Modifier votre profil',
@@ -507,7 +521,7 @@ $LANG = array(
 'L_PROFIL_MODERATOR'				=> 'Modérateur',
 'L_PROFIL_EDITOR'					=> 'Éditeur',
 'L_PROFIL_WRITER'					=> 'Rédacteur',
-'L_ADMIN'							=> '- Administration',
+'L_ADMIN'							=> 'Administration',
 'L_LOGIN'							=> 'Connecté en tant que',
 'L_ADMIN_LOGOUT'					=> 'Déconnexion',
 'L_ADMIN_LOGOUT_TITLE'				=> 'Quitter la session d\'administration',
@@ -531,7 +545,7 @@ $LANG = array(
 'L_MENU_CONFIG'						=> 'Paramètres',
 'L_MENU_PROFIL_TITLE'				=> 'Gérer votre profil utilisateur',
 'L_MENU_PROFIL'						=> 'Profil',
-'L_WARNING_INSTALLATION_FILE'		=> 'Le fichier install.php est présent à la racine de votre PluXml.<br />Pour des raisons de sécurité, il est fortement conseillé de le supprimer.',
+'L_WARNING_INSTALLATION_FILE'		=> 'Le fichier install.php est présent à la racine de votre PluXml.<br />Pour des raisons de sécurité, il est fortement conseillé de le <a class="lnkdelete" href="?del=install">supprimer</a>.',
 
 # user.php
 'L_USER_UNKNOWN'					=> 'Utilisateur inconnu',
@@ -561,5 +575,6 @@ $LANG = array(
 'L_HELP'							=> 'Aide',
 'L_HELP_TITLE'						=> 'Voir l\'aide',
 'L_BACK_TO_THEMES'					=> 'Retour à la page des thèmes',
+'L_CONFIG_THEME_UPDATE'				=> 'Modifier le thème',
 );
-?>
+?>
\ No newline at end of file
