@@ -2,6 +2,7 @@
 
 $LANG = array(
 
+'L_ID' 														=> '#',
 'L_MENU'													=> 'Menu',
 'L_UNKNOWN_ERROR'											=> 'Errore sconosciuto',
 'L_CONFIRM_DELETE'											=> 'Confermare l\'eliminazione ?',
@@ -14,6 +15,11 @@ $LANG = array(
 'L_DELETE'													=> 'Cancella',
 'L_DELETE_FILE' 				    						=> 'Cancella il file',
 'L_DELETE_FOLDER'				   							=> 'Eliminare la cartella',
+'L_DELETE_SUCCESSFUL'										=> 'Eliminazione di successo',
+'L_DELETE_FILE_ERR'											=> 'Errore durante l\'eliminazione del file',
+'L_RENAME_FILE_SUCCESSFUL'									=> 'File rinominato con successo',
+'L_RENAME_FILE_ERR'											=> 'Errore durante l\'elaborazione del file',
+'L_RENAME_FILE'												=> 'Rinomina il file',
 'L_THUMBNAIL'												=> 'Miniatura (facoltativo)',
 'L_THUMBNAIL_SELECTION'										=> 'Seleziona immagine',
 'L_THUMBNAIL_TITLE'											=> 'Immagine Titolo (facoltativo)',
@@ -128,6 +134,7 @@ $LANG = array(
 'L_SUBMIT_BUTTON'											=> 'Collegati',
 'L_ERR_WRONG_PASSWORD'										=> 'Nome utente e/o password non corretti',
 'L_POWERED_BY'												=> 'Powered by <a href="http://www.pluxml.org">PluXml</a>',
+'L_ERR_MAXLOGIN'											=> 'Troppi fallito login<br />Riprova tra% s minuti',
 'L_CAT_TITLE'												=> 'Gestione categorie',
 'L_CAT_LIST_ID'												=> 'ID',
 'L_CAT_LIST_ACTIVE'											=> 'Attiva',
@@ -221,14 +228,14 @@ $LANG = array(
 'L_ARTICLE_LIST_ACTION'										=> 'Azione',
 'L_CATEGORY_HOME'											=> 'Homepage',
 'L_CATEGORY_DRAFT'											=> 'Bozza',
-'L_ARTICLE_VIEW'											=> 'Visualizza',
 'L_ARTICLE_VIEW_TITLE'										=> 'Visualizza questo articolo sul sito',
 'L_ARTICLE_EDIT'											=> 'Modifica',
 'L_ARTICLE_EDIT_TITLE'										=> 'Modifica questo articolo',
 'L_NEW_COMMENTS_TITLE'										=> 'Commenti in attesa di pubblicazione',
 'L_VALIDATED_COMMENTS_TITLE'								=> 'Commenti pubblicati',
 'L_NO_ARTICLE'												=> 'Nessun articolo',
-'L_ARTICLES_SEARCH_BUTTON'									=> 'Cerca',
+'L_SEARCH'													=> 'Cerca',
+'L_SEARCH_PLACEHOLDER'										=> 'id o titolo',
 'L_ARTICLES_ALL_CATEGORIES'									=> 'Tutte le categorie ...',
 'L_ALL'														=> 'Tutte le',
 'L_ALL_PUBLISHED'											=> 'Edizione',
@@ -245,7 +252,8 @@ $LANG = array(
 'L_MEDIAS_DOCUMENTS'										=> 'Documenti',
 'L_MEDIAS_CREATE_FOLDER'									=> 'Crea una cartella',
 'L_MEDIAS_SUBMIT_FILE'										=> 'Invia',
-'L_MEDIAS_MAX_UPOLAD_FILE'									=> 'Dimensione max dei file',
+'L_MEDIAS_MAX_UPOLAD_FILE'									=> 'Dimensione massima dei file',
+'L_MEDIAS_MAX_POST_SIZE'									=> 'Dimensione massima dei dati',
 'L_MEDIAS_DIRECTORY'										=> 'Posizione',
 'L_MEDIAS_FOLDER'											=> 'File',
 'L_MEDIAS_NEW_FOLDER'										=> 'Nuova Cartella',
@@ -266,9 +274,15 @@ $LANG = array(
 'L_MEDIAS_ALIGN_CENTER'										=> 'Centro',
 'L_MEDIAS_ALIGN_RIGHT'										=> 'Diritto',
 'L_MEDIAS_RECREATE_THUMB'									=> 'Ricrea thumbnail',
+'L_MEDIAS_LINK_COPYCLP'                                     => 'Copia collegamento negli Appunti',
+'L_MEDIAS_LINK_COPYCLP_ERR'                                 => 'Impossibile copiare il link negli appunti',
+'L_MEDIAS_LINK_COPYCLP_DONE'                                => 'Link copiato',
+'L_MEDIAS_NEW_NAME'											=> 'Nuovo nome',
+'L_MEDIAS_RENAME'											=> 'Rinominare',
 'L_SORT_ASCENDING_DATE'										=> 'data ascendente',
 'L_SORT_DESCENDING_DATE'									=> 'data discendente',
 'L_SORT_ALPHABETICAL'										=> 'alfabetico',
+'L_SORT_RANDOM'												=> 'aleatorio',
 'L_OK'														=> 'Ok',
 'L_YES'														=> 'Si',
 'L_NO'														=> 'No',
@@ -281,6 +295,7 @@ $LANG = array(
 'L_CONFIG_VIEW_SORT'										=> 'Ordinamento degli articoli',
 'L_CONFIG_VIEW_BYPAGE'										=> 'Numero di articoli visualizzati per pagina',
 'L_CONFIG_VIEW_BYPAGE_ARCHIVES'								=> 'Numero di articoli visualizzati per pagina nell\'archivio',
+'L_CONFIG_VIEW_BYPAGE_TAGS'									=> 'Numero di articoli visualizzati per pagina nei tag',
 'L_CONFIG_VIEW_BYPAGE_ADMIN'								=> 'Numero di articoli visualizzati per pagina nel pannello di amministrazione',
 'L_CONFIG_VIEW_SORT_COMS'									=> 'Ordinamento dei commenti',
 'L_CONFIG_VIEW_BYPAGE_ADMIN_COMS'							=> 'Numero di commenti visualizzati per nel pannello di amministrazione',
@@ -369,6 +384,8 @@ $LANG = array(
 'L_PLUGINS_DELETE_SUCCESSFUL'								=> 'Cancellazione avvenuta con successo',
 'L_PLUGINS_CONFIG'											=> 'Configurazione',
 'L_PLUGINS_CONFIG_TITLE'									=> 'Configurazione del plugin',
+'L_PLUGINS_HELP'											=> 'Aiutare',
+'L_PLUGINS_HELP_TITLE'										=> 'Vedere Utilizzo del plug-in',
 'L_PLUGINS_REQUIREMENTS'									=> 'Prerequisiti',
 'L_PLUGINS_REQUIREMENTS_HELP'								=> 'Lista dei plugin presenti e attivi per attivare questo plugin',
 'L_PLUGINS_REQUIREMENTS_NONE'								=> 'Nessuno',
@@ -422,7 +439,7 @@ $LANG = array(
 'L_PROFIL_MODERATOR'										=> 'Moderatore',
 'L_PROFIL_EDITOR'											=> 'Editore',
 'L_PROFIL_WRITER'											=> 'Redattore',
-'L_ADMIN'													=> '- Amministrazione',
+'L_ADMIN'													=> 'Amministrazione',
 'L_LOGIN'													=> 'Connesso come',
 'L_ADMIN_LOGOUT'											=> 'Disconnettiti',
 'L_ADMIN_LOGOUT_TITLE'										=> 'Esci dal pannello di amministrazione',
@@ -446,7 +463,7 @@ $LANG = array(
 'L_MENU_CONFIG'												=> 'Parametri',
 'L_MENU_PROFIL_TITLE'										=> 'Gestisci il profilo',
 'L_MENU_PROFIL'												=> 'Profilo',
-'L_WARNING_INSTALLATION_FILE'								=> 'Il file install.php è presente nella radice di PluXml.<br />Per motivi di sicurezza, è fortemente consigliata la cancellazione.',
+'L_WARNING_INSTALLATION_FILE'								=> 'Il file install.php è presente nella radice di PluXml.<br />Per motivi di sicurezza, è fortemente consigliata la <a class="lnkdelete" href="?del=install">cancellazione</a>.',
 'L_USER_UNKNOWN'											=> 'Utente sconosciuto',
 'L_USER_LANG'												=> 'Lingua usata nel pannello di amministrazione',
 'L_USER_MAIL'												=> 'Indirizzo email',
@@ -474,5 +491,6 @@ $LANG = array(
 'L_BACK_TO_THEMES'											=> 'Torna alla pagina dei temi',
 'L_ERR_INVALID_DATE_CREATION'								=> 'Data di creazione non valida',
 'L_ERR_INVALID_DATE_UPDATE'									=> 'Data non valida aggiornato',
+'L_CONFIG_THEME_UPDATE'										=> 'Cambia Aspetto',
 );
 ?>
