@@ -2,6 +2,7 @@
 
 $LANG = array(
 
+'L_ID' 														=> '#',
 'L_MENU'													=> 'Menu',
 'L_UNKNOWN_ERROR'											=> 'Onbekende fout',
 'L_CONFIRM_DELETE'											=> 'Bevestig de verwijdering ?',
@@ -14,6 +15,11 @@ $LANG = array(
 'L_DELETE'													=> 'Verwijderen',
 'L_DELETE_FILE' 				    						=> 'Bestand verwijderen',
 'L_DELETE_FOLDER'				   							=> 'Map verwijderen',
+'L_DELETE_SUCCESSFUL'										=> 'Succesvol wissen',
+'L_DELETE_FILE_ERR'											=> 'Fout bij het verwijderen van het bestand',
+'L_RENAME_FILE_SUCCESSFUL'									=> 'Bestand met succes omgedoopt',
+'L_RENAME_FILE_ERR'											=> 'Fout bij het verwerken van het bestand',
+'L_RENAME_FILE'												=> 'Hernoem bestand',
 'L_THUMBNAIL'												=> 'Thumbnail (facultatief)',
 'L_THUMBNAIL_SELECTION'										=> 'Selecteer Afbeelding',
 'L_THUMBNAIL_TITLE'											=> 'Beeld (facultatief)',
@@ -128,6 +134,7 @@ $LANG = array(
 'L_SUBMIT_BUTTON'											=> 'Verzenden',
 'L_ERR_WRONG_PASSWORD'										=> 'Login en/of wachtwoord ongeldig',
 'L_POWERED_BY'												=> 'Gegenereerd door <a href="http://www.pluxml.org">PluXml</a>',
+'L_ERR_MAXLOGIN'											=> 'Te veel mislukte login<br />Probeer het over% s minuten',
 'L_CAT_TITLE'												=> 'Aanmaken en aanpassen van categorie?n',
 'L_CAT_LIST_ID'												=> 'ID',
 'L_CAT_LIST_ACTIVE'											=> 'Actief',
@@ -221,14 +228,14 @@ $LANG = array(
 'L_ARTICLE_LIST_ACTION'										=> 'Actie',
 'L_CATEGORY_HOME'											=> 'Home',
 'L_CATEGORY_DRAFT'											=> 'Klad',
-'L_ARTICLE_VIEW'											=> 'Bekijken',
 'L_ARTICLE_VIEW_TITLE'										=> 'Bekijk het artikel op de site',
 'L_ARTICLE_EDIT'											=> 'Aanpassen',
 'L_ARTICLE_EDIT_TITLE'										=> 'Artikel aanpassen',
 'L_NEW_COMMENTS_TITLE'										=> 'Commentaar die op goedkeuring wacht',
 'L_VALIDATED_COMMENTS_TITLE'								=> 'Geplubliceerde commentaar',
 'L_NO_ARTICLE'												=> 'Geen artikel',
-'L_ARTICLES_SEARCH_BUTTON'									=> 'Zoek',
+'L_SEARCH'													=> 'Zoek',
+'L_SEARCH_PLACEHOLDER'										=> 'artikel-ID of titel',
 'L_ARTICLES_ALL_CATEGORIES'									=> 'Alle categorie?n ...',
 'L_ALL'														=> 'Alle',
 'L_ALL_PUBLISHED'											=> 'Gepubliceerd',
@@ -245,7 +252,8 @@ $LANG = array(
 'L_MEDIAS_DOCUMENTS'										=> 'Documenten',
 'L_MEDIAS_CREATE_FOLDER'									=> 'Map aanmaken',
 'L_MEDIAS_SUBMIT_FILE'										=> 'Versturen',
-'L_MEDIAS_MAX_UPOLAD_FILE'									=> 'Max. grootte bestand',
+'L_MEDIAS_MAX_UPOLAD_FILE'									=> 'Maximale grootte bestand',
+'L_MEDIAS_MAX_POST_SIZE'									=> 'Maximale gegevensgrootte',
 'L_MEDIAS_DIRECTORY'										=> 'Locatie',
 'L_MEDIAS_FOLDER'											=> 'Bestand',
 'L_MEDIAS_NEW_FOLDER'										=> 'Nieuwe map',
@@ -266,9 +274,15 @@ $LANG = array(
 'L_MEDIAS_ALIGN_CENTER'										=> 'Centrum',
 'L_MEDIAS_ALIGN_RIGHT'										=> 'Rechts',
 'L_MEDIAS_RECREATE_THUMB'									=> 'Opnieuw thumbnail',
+'L_MEDIAS_LINK_COPYCLP'                                     => 'Kopieer Link naar klembord',
+'L_MEDIAS_LINK_COPYCLP_ERR'                                 => 'Niet in staat om de link te kopiëren naar het klembord',
+'L_MEDIAS_LINK_COPYCLP_DONE'                                => 'Koppeling gekopieerd',
+'L_MEDIAS_NEW_NAME'											=> 'Nieuwe naam',
+'L_MEDIAS_RENAME'											=> 'Andere naam geven',
 'L_SORT_ASCENDING_DATE'										=> 'datum oplopend',
 'L_SORT_DESCENDING_DATE'									=> 'datum aflopend',
 'L_SORT_ALPHABETICAL'										=> 'alfabetisch',
+'L_SORT_RANDOM'												=> 'onzeker',
 'L_OK'														=> 'Ok',
 'L_YES'														=> 'Ja',
 'L_NO'														=> 'Neen',
@@ -281,6 +295,7 @@ $LANG = array(
 'L_CONFIG_VIEW_SORT'										=> 'Artikels sorteren',
 'L_CONFIG_VIEW_BYPAGE'										=> 'Aantal artikels per pagina',
 'L_CONFIG_VIEW_BYPAGE_ARCHIVES'								=> 'Aantal artikels par pagina in archief',
+'L_CONFIG_VIEW_BYPAGE_TAGS'									=> 'Aantal artikels per pagina in tags',
 'L_CONFIG_VIEW_BYPAGE_ADMIN'								=> 'Aantal artikels per pagina in administratie-gedeelte',
 'L_CONFIG_VIEW_SORT_COMS'									=> 'Commentaar sorteren',
 'L_CONFIG_VIEW_BYPAGE_ADMIN_COMS'							=> 'Aantal commentaren per pagina in administratie-gedeelte',
@@ -369,6 +384,8 @@ $LANG = array(
 'L_PLUGINS_DELETE_SUCCESSFUL'								=> 'Verwijdering succesvl doorgevoerd',
 'L_PLUGINS_CONFIG'											=> 'Configuratie',
 'L_PLUGINS_CONFIG_TITLE'									=> 'Configuratie van de plugin',
+'L_PLUGINS_HELP'											=> 'Helpen',
+'L_PLUGINS_HELP_TITLE'										=> 'Zie Met behulp van de plugin',
 'L_PLUGINS_REQUIREMENTS'									=> 'Benodigdheden',
 'L_PLUGINS_REQUIREMENTS_HELP'								=> 'Lijst van beschikbare en actieve plugins voor deze plugin',
 'L_PLUGINS_REQUIREMENTS_NONE'								=> 'Geen',
@@ -422,7 +439,7 @@ $LANG = array(
 'L_PROFIL_MODERATOR'										=> 'Moderator',
 'L_PROFIL_EDITOR'											=> 'Editeur',
 'L_PROFIL_WRITER'											=> 'Redacteur',
-'L_ADMIN'													=> '- Administratie',
+'L_ADMIN'													=> 'Administratie',
 'L_LOGIN'													=> 'Aangemeld als',
 'L_ADMIN_LOGOUT'											=> 'Afmelden',
 'L_ADMIN_LOGOUT_TITLE'										=> 'Sluit adminstratie-sessie',
@@ -446,7 +463,7 @@ $LANG = array(
 'L_MENU_CONFIG'												=> 'Parameters',
 'L_MENU_PROFIL_TITLE'										=> 'Uw gebruikersprofiel beheren',
 'L_MENU_PROFIL'												=> 'Profiel',
-'L_WARNING_INSTALLATION_FILE'								=> 'het bestand install.php is nog aanwezig in de basismap van uw PluXml.<br />Om veiligheidsredenen raden wij u aan dit bestand te verwijderen of te hernoemen.',
+'L_WARNING_INSTALLATION_FILE'								=> 'het bestand install.php is nog aanwezig in de basismap van uw PluXml.<br />Om veiligheidsredenen raden wij u aan dit bestand te <a class="lnkdelete" href="?del=install">verwijderen</a> of te hernoemen.',
 'L_USER_UNKNOWN'											=> 'Onbekende gebruiker',
 'L_USER_LANG'												=> 'Gebruikte taal in adminstratief gedeelte',
 'L_USER_MAIL'												=> 'Emailadres',
@@ -472,6 +489,7 @@ $LANG = array(
 'L_HELP'													=> 'Hulp',
 'L_HELP_TITLE'												=> 'Zie hulp',
 'L_BACK_TO_THEMES'											=> 'Terug naar de onderwerpen van de pagina',
+'L_CONFIG_THEME_UPDATE'										=> 'Change Theme',
 'L_ERR_INVALID_DATE_CREATION'								=> 'Ongeldige aanmaakdatum',
 'L_ERR_INVALID_DATE_UPDATE'									=> 'Ongeldige datum bijgewerkt',
 );
