@@ -2,6 +2,7 @@
 
 $LANG = array(
 
+'L_ID' 								=> '#',
 'L_MENU'							=> 'Menú',
 'L_UNKNOWN_ERROR'					=> 'Error desconeguda',
 'L_CONFIRM_DELETE'					=> 'Confirmar la supression ?',
@@ -14,12 +15,17 @@ $LANG = array(
 'L_DELETE' 						    => 'Suprimir',
 'L_DELETE_FILE' 				  	=> 'Escafar fiquièr',
 'L_DELETE_FOLDER'				   	=> 'Escafar dorsièr',
+'L_DELETE_SUCCESSFUL'				=> 'Supression efectuada amb succès',
+'L_DELETE_FILE_ERR'					=> 'Error pendent la supression del fichièr',
+'L_RENAME_FILE_SUCCESSFUL'			=> 'Modificacion efectuada amb succès',
+'L_RENAME_FILE_ERR'					=> 'Error pendent lo tractament del fichièr',
+'L_RENAME_FILE'						=> 'Modificacion del fichièr',
 'L_THUMBNAIL'						=> 'Imatge a la una (facultatiu)',
 'L_THUMBNAIL_SELECTION'				=> 'Seleccionar un imatge',
 'L_THUMBNAIL_TITLE'					=> 'Títol de l\'imatge (facultatiu)',
 'L_THUMBNAIL_ALT'					=> 'Tèxte alternatiu de l\'imatge (facultatiu)',
 'L_ERR_INVALID_DATE_CREATION'		=> 'Data de creacion invalida',
-'L_ERR_INVALID_DATE_UPDATE'			=> 'Data de misa a jorn invalid',
+'L_ERR_INVALID_DATE_UPDATE'			=> 'Data de mesa a jorn invalida',
 
 # class.plx.admin.php
 
@@ -111,7 +117,7 @@ $LANG = array(
 'L_ALLOW_COMMENTS' 					=> 'Autorizar los comentaris',
 'L_ARTICLE_URL_FIELD' 				=> 'Url',
 'L_ARTICLE_URL_FIELD_TITLE' 		=> 'l\'URL s\'emplís automaticament a la creacion',
-'L_ARTICLE_TEMPLATE_FIELD' 			=> 'Template',
+'L_ARTICLE_TEMPLATE_FIELD' 			=> 'Modèl',
 'L_ARTICLE_MANAGE_COMMENTS'			=> 'Gerir los comentaris',
 'L_ARTICLE_MANAGE_COMMENTS_TITLE'	=> 'Gerir los comentaris d\'aqueste article',
 'L_ARTICLE_NEW_COMMENT'				=> 'Escriure un comentari',
@@ -137,17 +143,19 @@ $LANG = array(
 'L_AUTH_PAGE_TITLE'					=> 'Pagina d\'autentificacion',
 'L_LOGOUT_SUCCESSFUL'				=> 'Sètz estat corrèctament desconnectat',
 'L_LOGIN_PAGE'						=> 'Connexion a la zòna d\'administracion',
-'L_AUTH_LOGIN_FIELD'				=> 'Login de connexion',
+'L_AUTH_LOGIN_FIELD'				=> 'Identificant de connexion',
 'L_AUTH_PASSWORD_FIELD'				=> 'Senhal',
 'L_SUBMIT_BUTTON'					=> 'Validar',
-'L_ERR_WRONG_PASSWORD' 				=> 'Login e/o senhal incorrèct',
+'L_ERR_WRONG_PASSWORD' 				=> 'Identificant e/o senhal incorrèct',
 'L_POWERED_BY'						=> 'Generat per <a href="http://www.pluxml.org">PluXml</a>',
+'L_ERR_MAXLOGIN'					=> 'Nombre de pròvas atent<br />Tornatz ensajar dins %s minutas',
 
 #
 
 'L_SORT_ASCENDING_DATE'				=> 'data creissenta',
 'L_SORT_DESCENDING_DATE'			=> 'data decreissenta',
 'L_SORT_ALPHABETICAL'				=> 'alfabetic',
+'L_SORT_RANDOM'						=> 'aleatòri',
 'L_YES' 							=> 'Òc',
 'L_NO' 								=> 'Non',
 'L_OK'								=> 'Ok',
@@ -179,7 +187,7 @@ $LANG = array(
 'L_EDITCAT_PAGE_TITLE'				=> 'Edicion de las opcions de la categoria',
 'L_EDITCAT_DESCRIPTION'				=> 'Descripcion',
 'L_EDITCAT_DISPLAY_HOMEPAGE'		=> 'Afichar los articles d\'aquesta categoria sus la pagina d\'acuèlh',
-'L_EDITCAT_TEMPLATE'				=> 'Template',
+'L_EDITCAT_TEMPLATE'				=> 'Modèl',
 'L_EDITCAT_BACK_TO_PAGE'			=> 'Tornar a la lista de las categorias',
 'L_EDITCAT_UPDATE'					=> 'Metre a jorn aquesta categoria',
 'L_EDITCAT_TITLE_HTMLTAG'			=> 'Contengut balisa title (opcion)',
@@ -202,8 +210,8 @@ $LANG = array(
 'L_COMMENT_TYPE_FIELD'				=> 'Tipe de comentari',
 'L_COMMENT_DATE_FIELD'				=> 'Data e ora de publicacion',
 'L_COMMENT_IP_FIELD'				=> 'Ip',
-'L_COMMENT_SITE_FIELD'				=> 'Siti',
-'L_COMMENT_EMAIL_FIELD'				=> 'Corric',
+'L_COMMENT_SITE_FIELD'				=> 'Site',
+'L_COMMENT_EMAIL_FIELD'				=> 'Corrièl',
 'L_COMMENT_STATUS_FIELD'			=> 'Estatut',
 'L_COMMENT_LINKED_ARTICLE_FIELD'	=> 'Article estacat',
 'L_COMMENT_ARTICLE_FIELD'			=> 'Comentari',
@@ -236,7 +244,7 @@ $LANG = array(
 # comments.php
 
 'L_COMMENTS_ARTICLE_SCOPE' 			=> 'Article',
-'L_COMMENTS_GLOBAL_SCOPE'			=> 'siti entièr',
+'L_COMMENTS_GLOBAL_SCOPE'			=> 'site entièr',
 'L_COMMENTS_LIST_DATE'				=> 'Data',
 'L_COMMENTS_LIST_AUTHOR'			=> 'Autor',
 'L_COMMENTS_LIST_MESSAGE'			=> 'Messatge',
@@ -257,7 +265,8 @@ $LANG = array(
 
 # index.php
 
-'L_ARTICLES_SEARCH_BUTTON'			=> 'Recercar',
+'L_SEARCH'							=> 'Recercar',
+'L_SEARCH_PLACEHOLDER'				=> 'identificant o títol',
 'L_ARTICLES_ALL_CATEGORIES'			=> 'Totas las categorias...',
 'L_ALL'								=> 'Totes',
 'L_ALL_PUBLISHED'					=> 'Publicats',
@@ -276,8 +285,7 @@ $LANG = array(
 'L_ARTICLE_LIST_ACTION'				=> 'Accion',
 'L_CATEGORY_HOME'					=> 'Pagina d\'acuèlh',
 'L_CATEGORY_DRAFT'					=> 'Borrolhon',
-'L_ARTICLE_VIEW'					=> 'Visualizar',
-'L_ARTICLE_VIEW_TITLE'				=> 'Visualizar aquel article sul siti',
+'L_ARTICLE_VIEW_TITLE'				=> 'Visualizar aquel article sul site',
 'L_ARTICLE_EDIT'					=> 'Editar',
 'L_ARTICLE_EDIT_TITLE'				=> 'Editar aquel article',
 'L_NEW_COMMENTS_TITLE' 				=> 'Comentaris en espèra de validacion',
@@ -291,6 +299,7 @@ $LANG = array(
 'L_MEDIAS_DIRECTORY' 				=> 'Emplaçament',
 'L_MEDIAS_BACK'						=> 'Retorn a la lista dels mèdia',
 'L_MEDIAS_MAX_UPOLAD_FILE'			=> 'Talha maxi dels fichièrs',
+'L_MEDIAS_MAX_POST_SIZE'			=> 'Talha maxi de las donadas',
 'L_MEDIAS_SUBMIT_FILE'				=> 'Enviar',
 'L_MEDIAS_IMAGES'					=> 'Imatges',
 'L_MEDIAS_DOCUMENTS'				=> 'Documents',
@@ -304,7 +313,7 @@ $LANG = array(
 'L_MEDIAS_DATE'						=> 'Data',
 'L_MEDIAS_DIMENSIONS'				=> 'Dimensions',
 'L_MEDIAS_NO_FILE'					=> 'Pas cap de fichièr',
-'L_MEDIAS_RESIZE'					=> 'Redimensionar imatges',
+'L_MEDIAS_RESIZE'					=> 'Retalhar los imatges',
 'L_MEDIAS_RESIZE_NO'				=> 'Talha originala',
 'L_MEDIAS_THUMBS'					=> 'Crear miniaturas',
 'L_MEDIAS_THUMBS_NONE'				=> 'Pas de miniatura',
@@ -318,6 +327,11 @@ $LANG = array(
 'L_MEDIAS_ALIGN_CENTER'				=> 'Centre',
 'L_MEDIAS_ALIGN_RIGHT'				=> 'Drecha',
 'L_MEDIAS_RECREATE_THUMB'			=> 'Recrear miniaturas',
+'L_MEDIAS_LINK_COPYCLP'             => 'Copiar lo ligam al quichapapièrs',
+'L_MEDIAS_LINK_COPYCLP_ERR'         => 'Fracàs de la còpia del ligam al quichapapièrs',
+'L_MEDIAS_LINK_COPYCLP_DONE'        => 'Ligam copiat',
+'L_MEDIAS_NEW_NAME'					=> 'Novèl nom',
+'L_MEDIAS_RENAME'					=> 'Renommar',
 
 # parametres_affichage.php
 
@@ -328,6 +342,7 @@ $LANG = array(
 'L_CONFIG_VIEW_SORT'				=> 'Tria dels articles',
 'L_CONFIG_VIEW_BYPAGE'				=> 'Nombre d\'articles afichats per pagina',
 'L_CONFIG_VIEW_BYPAGE_ARCHIVES'		=> 'Nombre d\'articles afichats per pagina dins los archius',
+'L_CONFIG_VIEW_BYPAGE_TAGS'			=> 'Nombre d\'articles afichats per pagina dins los mots claus',
 'L_CONFIG_VIEW_BYPAGE_ADMIN'		=> 'Nombre d\'articles afichats per pagina dins l\'administracion',
 'L_CONFIG_VIEW_SORT_COMS'			=> 'Tria dels comentaris',
 'L_CONFIG_VIEW_BYPAGE_ADMIN_COMS'	=> 'Nombre de comentaris afichats per pagina dins l\'administracion',
@@ -335,14 +350,14 @@ $LANG = array(
 'L_CONFIG_VIEW_THUMBS'				=> 'Talha de las miniaturas (largor x nautor)',
 'L_CONFIG_VIEW_HOMESTATIC'			=> 'Utilizar una pagina estatica coma pagina d\'acuèlh',
 'L_CONFIG_VIEW_HOMESTATIC_ACTIVE'	=> 'Atencion aquela pagina es inactiva',
-'L_CONFIG_VIEW_PLUXML_RESSOURCES'	=> 'Telecargar d\'autres tèmas sus <a href="http://ressources.pluxml.org">ressources.pluxml.org</a>.',
+'L_CONFIG_VIEW_PLUXML_RESSOURCES'	=> 'Telecargar mai tèmas sus <a href="http://ressources.pluxml.org">ressources.pluxml.org</a>.',
 'L_CONFIG_VIEW_BYPAGE_FEEDS'		=> 'Nombre d\'articles/comentaris afichats suls fils Rss',
 'L_CONFIG_VIEW_FEEDS_HEADLINE'		=> 'Afichar pas que lo chapô dins los flux Rss dels articles',
 'L_CONFIG_VIEW_FEEDS_HEADLINE_HELP'	=> 'Se lo chapô es void, lo contengut es afichat',
 'L_CONFIG_VIEW_FEEDS_FOOTER'		=> 'Tèxte a ajustar coma signatura al bas de cada flux Rss dels articles',
 'L_CONFIG_VIEW_UPDATE'				=> 'Modificar las opcions d\'afichatge',
 'L_CONFIG_VIEW_DISPLAY_EMPTY_CAT'	=> 'Afichar las categorias sens article',
-'L_CONFIG_HOMETEMPLATE'				=> 'Template de la pagina d\'acuèlh',
+'L_CONFIG_HOMETEMPLATE'				=> 'Modèl de la pagina d\'acuèlh',
 
 # parametres_avances.php
 
@@ -364,13 +379,13 @@ $LANG = array(
 'L_CONFIG_ADVANCED_PLUGINS_FOLDER'	=> 'Emplaçament dels plugins (dorsièr)',
 'L_CONFIG_ADVANCED_CONFIG_FOLDER'	=> 'Emplaçament dels fichièrs de configuracion (dorsièr)',
 'L_CONFIG_ADVANCED_UPDATE'			=> 'Modificar la configuracion avançada',
-'L_CONFIG_CUSTOM_CSSADMIN_PATH'		=> 'Emplacement et nom du fichier css personnel pour customisation de l\'interface d\'administration (option)',
+'L_CONFIG_CUSTOM_CSSADMIN_PATH'		=> 'Lòc e nom del fichièr css personnal per personalizar l\'interfàcia d\'administracion (opcion)',
 
 # parametres_base.php
 
 'L_CONFIG_BASE_CONFIG_TITLE'		=> 'Configuracion de basa',
-'L_CONFIG_BASE_SITE_TITLE'			=> 'Títol del siti',
-'L_CONFIG_BASE_SITE_SLOGAN'			=> 'Sos-títol/descripcion del siti',
+'L_CONFIG_BASE_SITE_TITLE'			=> 'Títol del site',
+'L_CONFIG_BASE_SITE_SLOGAN'			=> 'Sos-títol/descripcion del site',
 'L_CONFIG_BASE_URL_HELP'			=> 'Oblidar pas lo slash a la fin',
 'L_CONFIG_BASE_DEFAULT_LANG'		=> 'Lenga per defaut del siti',
 'L_CONFIG_BASE_TIMEZONE'			=> 'Fus orari',
@@ -378,8 +393,8 @@ $LANG = array(
 'L_CONFIG_BASE_MODERATE_COMMENTS'	=> 'Moderar los comentaris a la creacion',
 'L_CONFIG_BASE_MODERATE_ARTICLES'	=> 'Moderar los articles pels perfils Redactor e Editor',
 'L_CONFIG_BASE_UPDATE'				=> 'Modificar la configuracion de basa',
-'L_CONFIG_META_DESCRIPTION'			=> 'Contengut de la balisa meta "descripcion" del siti (opcion)',
-'L_CONFIG_META_KEYWORDS'			=> 'Contengut de las balisas meta "keywords" del siti (opcion)',
+'L_CONFIG_META_DESCRIPTION'			=> 'Contengut de la balisa meta "descripcion" del site (opcion)',
+'L_CONFIG_META_KEYWORDS'			=> 'Contengut de las balisas meta "keywords" del site (opcion)',
 
 # parametres_edittpl.php
 
@@ -396,7 +411,7 @@ $LANG = array(
 'L_CONFIG_INFOS_NB_STATICS'			=> 'Nombre de paginas estaticas :',
 'L_CONFIG_INFOS_WRITER'				=> 'Nom del redactor en session :',
 'L_PLUXML_CHECK_VERSION'			=> 'Verificacion del numerò de version de PluXml sul siti oficial PluXml.org',
-'L_PLUXML_UPDATE_UNAVAILABLE'		=> 'Impossible de verificar las mesas a jorn mentre que \'allow_url_fopen\' es desactivat sul sistème',
+'L_PLUXML_UPDATE_UNAVAILABLE'		=> 'Impossible de verificar las mesas a jorn mentre que \'allow_url_fopen\' es desactivat sul sistèma',
 'L_PLUXML_UPDATE_ERR'				=> 'La verificacion de mesa a jorn s\'es abocada per una rason desconeguda',
 'L_PLUXML_UPTODATE'					=> 'Utilizatz la darrièra version de PluXml',
 'L_PLUXML_UPDATE_AVAILABLE'			=> 'Una novèla version de PluXml es sortida ! La podètz telecargar sus',
@@ -412,13 +427,12 @@ $LANG = array(
 'L_CONFIG_USERS_UPDATE'				=> 'Modificar la lista dels utilizators',
 'L_ERR_LOGIN_ALREADY_EXISTS'		=> 'Identificant de connexion ja utilizat',
 'L_ERR_USERNAME_ALREADY_EXISTS'		=> 'Nom d\'utilizator ja utilizat',
-'L_CONFIG_USERS_DELETE_CONFIRM'		=> 'Suprimir los utilizators seleccionats ?',
 
 # parametre_plugins.php
 
 'L_BACK_TO_PLUGINS'					=> 'Tornar a la pagina dels plugins',
 'L_NO_PLUGIN'						=> 'Pas cap de plugin',
-'L_PLUGIN_NO_CONFIG'				=> 'Plugin non configurat',
+'L_PLUGIN_NO_CONFIG'				=> 'Plugin pas configurat',
 'L_PLUGINS_CSS'						=> 'Còdi css',
 'L_PLUGINS_CSS_TITLE'				=> 'Editar lo còdi css del plugin',
 'L_CONTENT_FIELD_FRONTEND'			=> 'Contengut fichièr css siti',
@@ -436,6 +450,8 @@ $LANG = array(
 'L_PLUGINS_DELETE_SUCCESSFUL'		=> 'Supression efectuada amb succès',
 'L_PLUGINS_CONFIG'					=> 'Configuracion',
 'L_PLUGINS_CONFIG_TITLE'			=> 'Configuracion del plugin',
+'L_PLUGINS_HELP'					=> 'Ajuda',
+'L_PLUGINS_HELP_TITLE'				=> 'Veire l\'ajuda del plugin',
 'L_PLUGINS_REQUIREMENTS'			=> 'Pre-requesit',
 'L_PLUGINS_REQUIREMENTS_HELP'		=> 'Lista dels plugins presents e actius per activar aqueste plugin',
 'L_PLUGINS_REQUIREMENTS_NONE'		=> 'Cap',
@@ -452,7 +468,7 @@ $LANG = array(
 'L_PROFIL'							=> 'Perfil',
 'L_PROFIL_LOGIN'					=> 'Identificant de connexion',
 'L_PROFIL_USER'						=> 'Nom d\'utilizator',
-'L_PROFIL_MAIL'						=> 'Adreça email',
+'L_PROFIL_MAIL'						=> 'Adreça de corrièl',
 'L_PROFIL_ADMIN_LANG'				=> 'Lenga utilizada dins l\'administracion',
 'L_PROFIL_INFOS'					=> 'Informacions',
 'L_PROFIL_UPDATE'					=> 'Modificar vòstre perfil',
@@ -467,7 +483,7 @@ $LANG = array(
 'L_STATIC_UNKNOWN_PAGE'				=> 'Aquela pagina estatica existís pas o existís pas pus !',
 'L_STATIC_TITLE'					=> 'Edicion del còdi sorga de la pagina estatica',
 'L_STATIC_VIEW_PAGE'				=> 'Visualizar la pagina',
-'L_STATIC_ON_SITE'					=> 'sul siti',
+'L_STATIC_ON_SITE'					=> 'sul site',
 'L_STATIC_UPDATE'					=> 'Enregistrar aquela pagina estatica',
 'L_STATIC_TITLE_HTMLTAG'			=> 'Contengut balisa títol (opcion)',
 'L_STATIC_META_DESCRIPTION'			=> 'Contengut de la balisa meta "descripcion" per aquela pagina estatica (opcion)',
@@ -484,7 +500,7 @@ $LANG = array(
 'L_STATICS_ORDER'					=> 'Òrdre',
 'L_STATICS_MENU'					=> 'Menú',
 'L_STATICS_ACTION'					=> 'Accion',
-'L_STATICS_TEMPLATE_FIELD'			=> 'Template',
+'L_STATICS_TEMPLATE_FIELD'			=> 'Modèl',
 'L_STATICS_PAGE_HOME'				=> 'Definir en tant que pagina d\'acuèlh',
 'L_STATICS_HOME_PAGE' 			 	=> 'Pagina<br />d\'acuèlh',
 'L_PAGE'							=> 'Pagina',
@@ -500,8 +516,8 @@ $LANG = array(
 'L_PROFIL_MANAGER'					=> 'Gestionari',
 'L_PROFIL_MODERATOR'				=> 'Moderator',
 'L_PROFIL_EDITOR'					=> 'Editor',
-'L_PROFIL_WRITER'					=> 'Rédactor',
-'L_ADMIN'							=> '- Administracion',
+'L_PROFIL_WRITER'					=> 'Redactor',
+'L_ADMIN'							=> 'Administracion',
 'L_LOGIN'							=> 'Connectat en tant que',
 'L_ADMIN_LOGOUT'					=> 'Desconnexion',
 'L_ADMIN_LOGOUT_TITLE'				=> 'Quitar la session d\'administracion',
@@ -517,20 +533,20 @@ $LANG = array(
 'L_MENU_STATICS'					=> 'Paginas estaticas',
 'L_MENU_COMMENTS_TITLE'				=> 'Lista e modificacion dels comentaris',
 'L_MENU_COMMENTS'					=> 'Comentaris',
-'L_MENU_MEDIAS_TITLE'				=> 'Uploader e inserir un media',
+'L_MENU_MEDIAS_TITLE'				=> 'Enviar e inserir un media',
 'L_MENU_MEDIAS'						=> 'Mèdia',
 'L_MENU_CATEGORIES_TITLE'			=> 'Crear, gerir, editar las categorias',
 'L_MENU_CATEGORIES'					=> 'Categorias',
 'L_MENU_CONFIG_TITLE'				=> 'Configurar PluXml',
-'L_MENU_CONFIG'						=> 'Paramètras',
+'L_MENU_CONFIG'						=> 'Paramètres',
 'L_MENU_PROFIL_TITLE'				=> 'Gerir vòstre perfil utilizator',
 'L_MENU_PROFIL'						=> 'Perfil',
-'L_WARNING_INSTALLATION_FILE'		=> 'Lo fichièr install.php es present a la raiç de vòstre PluXml.<br />Per de rasons de seguretat, es fòrtament conselhat d\'o suprimir.',
+'L_WARNING_INSTALLATION_FILE'		=> 'Lo fichièr install.php es present a la raiç de vòstre PluXml.<br />Per de rasons de seguretat, es fòrtament conselhat d\'o <a class="lnkdelete" href="?del=install">suprimir</a>.',
 
 # user.php
 'L_USER_UNKNOWN'					=> 'Utilizator desconegut',
 'L_USER_LANG'						=> 'Lenga utilizada dins l\'administracion',
-'L_USER_MAIL'						=> 'Adreça email',
+'L_USER_MAIL'						=> 'Adreça de corrièl',
 'L_USER_INFOS'						=> 'Informacions',
 'L_USER_UPDATE'						=> 'Metre a jorn aquel utilizator',
 'L_USER_PAGE_TITLE'					=> 'Edicion de las opcions de l\'utilizator',
@@ -550,10 +566,11 @@ $LANG = array(
 'L_MENU_CONFIG_INFOS'				=> 'Informacions',
 'L_MENU_CONFIG_PLUGINS_TITLE'		=> 'Gerir los plugins',
 'L_MENU_CONFIG_PLUGINS'				=> 'Plugins',
-'L_THEMES'							=> 'Themes',
+'L_THEMES'							=> 'Tèmas',
 'L_THEMES_TITLE'					=> 'Gerir los themes',
 'L_HELP'							=> 'Ajuda',
-'L_HELP_TITLE'						=> 'Véser l\'ajuda',
+'L_HELP_TITLE'						=> 'Veire l\'ajuda',
 'L_BACK_TO_THEMES'					=> 'Tornar a la lista dels tèmas',
+'L_CONFIG_THEME_UPDATE'				=> 'Modificar del tèma',
 );
-?>
\ No newline at end of file
+?>
