@@ -17,16 +17,20 @@ $LANG = array(
 'L_ERR_PLUXML_ALREADY_INSTALLED'	=> 'PluXml es ja configurat !',
 'L_ERR_MISSING_USER'				=> 'Volgatz entre-senhar lo nom del redactor !',
 'L_ERR_MISSING_LOGIN'				=> 'Volgatz entre-senhar lo login de connexion !',
-'L_ERR_MISSING_PASSWORD'			=> 'Volgatz entre-senhar un mot de Santa Clara !',
-'L_ERR_PASSWORD_CONFIRMATION'		=> 'Confirmacion del mot de Santa Clara incorrècta !',
+'L_ERR_MISSING_PASSWORD'			=> 'Volgatz entre-senhar un senhal !',
+'L_ERR_PASSWORD_CONFIRMATION'		=> 'Confirmacion del senhal incorrècta !',
 'L_PLUXML_INSTALLATION'				=> 'Installacion de PluXml',
 'L_SITE_DESCRIPTION'				=> 'Blòg o Cms a l\'Xml !',
 'L_VERSION'							=> 'version',
 'L_USERNAME'						=> 'Nom de l\'administrator',
 'L_LOGIN'							=> 'Identificant de connexion a l\'administracion',
-'L_PASSWORD'						=> 'Mot de Santa Clara',
-'L_PASSWORD_CONFIRMATION'			=> 'Confirmacion del mot de Santa Clara',
+'L_PASSWORD'						=> 'Senhal',
+'L_PASSWORD_CONFIRMATION'			=> 'Confirmacion del senhal',
 'L_INPUT_INSTALL'					=> 'Installar',
 'L_TIMEZONE'						=> 'Fus orari',
+'L_PWD_VERY_WEAK'					=> 'Senhal fòrça feble',
+'L_PWD_WEAK'						=> 'Senhal feble',
+'L_PWD_GOOD'						=> 'Senhal bon',
+'L_PWD_STRONG'						=> 'Senhal fòrt',
 );
-?>
\ No newline at end of file
+?>
