@@ -2,16 +2,24 @@
 
 $LANG = array(
 
+'L_ID' 								=> '#',
 'L_MENU'							=> 'Menu',
 'L_UNKNOWN_ERROR'					=> 'Nieznany błąd',
 'L_CONFIRM_DELETE'					=> 'Na pewno chcesz usunąć ?',
 'L_SAVE_FILE'						=> 'Zapisz plik',
 'L_SAVE_FILE_SUCCESSFULLY'			=> 'Plik został pomyślnie zapisany',
 'L_SAVE_FILE_ERROR'					=> 'Wystąpił błąd podczas zapisywania pliku',
-
+'L_REPLY'							=> 'Odpowiedź',
+'L_REPLY_TO'						=> 'Odpowiedź',
+'L_CANCEL'							=> 'Anulować',
 'L_DELETE' 						    => 'Usuń',
 'L_DELETE_FILE' 				    => 'Usuń plik',
 'L_DELETE_FOLDER'				    => 'Usuń folder',
+'L_DELETE_SUCCESSFUL'				=> 'Skuteczne usuwanie',
+'L_DELETE_FILE_ERR'					=> 'Błąd podczas usuwania pliku',
+'L_RENAME_FILE_SUCCESSFUL'			=> 'Plik przemianowany powodzeniem',
+'L_RENAME_FILE_ERR'					=> 'Błąd podczas przetwarzania pliku',
+'L_RENAME_FILE'						=> 'Zmień nazwę pliku',
 'L_THUMBNAIL'						=> 'Miniaturka (opcjonalnie)',
 'L_THUMBNAIL_SELECTION'				=> 'Wybierz zdjęcie',
 'L_THUMBNAIL_TITLE'					=> 'Tytuł zdjęcia (opcjonalnie)',
@@ -140,12 +148,15 @@ $LANG = array(
 'L_SUBMIT_BUTTON'					=> 'Zaloguj',
 'L_ERR_WRONG_PASSWORD' 				=> 'Login i / lub hasło niepoprawne',
 'L_POWERED_BY'						=> 'Silnik <a href="http://www.pluxml.org">PluXml</a>',
+'L_ERR_MAXLOGIN'					=> 'Zbyt wielu nieudanych<br />ponownych prób logowania w% s minut',
 
 #
 
 'L_SORT_ASCENDING_DATE'				=> 'data rosnąca',
 'L_SORT_DESCENDING_DATE'			=> 'data malejąco',
 'L_SORT_ALPHABETICAL'				=> 'alfabetycznie',
+'L_SORT_RANDOM'						=> '
+przypadkowy',
 'L_YES' 							=> 'Tak',
 'L_NO' 								=> 'Nie',
 'L_OK'								=> 'OK',
@@ -255,7 +266,8 @@ $LANG = array(
 
 # index.php
 
-'L_ARTICLES_SEARCH_BUTTON'			=> 'Szukaj',
+'L_SEARCH'							=> 'Szukaj',
+'L_SEARCH_PLACEHOLDER'				=> 'id lub tytuł',
 'L_ARTICLES_ALL_CATEGORIES'			=> 'Wszystkie kategorie...',
 'L_ALL'								=> 'Wszystkie',
 'L_ALL_PUBLISHED'					=> 'Opublikowane',
@@ -274,7 +286,6 @@ $LANG = array(
 'L_ARTICLE_LIST_ACTION'				=> 'Akcja',
 'L_CATEGORY_HOME'					=> 'Start',
 'L_CATEGORY_DRAFT'					=> 'Projekt',
-'L_ARTICLE_VIEW'					=> 'Podgląd',
 'L_ARTICLE_VIEW_TITLE'				=> 'Zobacz ten post na stronie',
 'L_ARTICLE_EDIT'					=> 'Edytuj',
 'L_ARTICLE_EDIT_TITLE'				=> 'Edytuj ten post',
@@ -284,38 +295,44 @@ $LANG = array(
 
 # medias.php
 
-'L_MEDIAS_FILENAME'					=> 'Nom du fichier',
-'L_MEDIAS_TITLE'					=> 'Gestion des médias',
-'L_MEDIAS_DIRECTORY' 				=> 'Emplacement',
-'L_MEDIAS_BACK'						=> 'Retour à la liste des médias',
-'L_MEDIAS_MAX_UPOLAD_FILE'			=> 'Taille maxi des fichiers',
-'L_MEDIAS_SUBMIT_FILE'				=> 'Envoyer',
-'L_MEDIAS_IMAGES'					=> 'Images',
-'L_MEDIAS_DOCUMENTS'				=> 'Documents',
-'L_MEDIAS_ADD_FILE'					=> 'Ajouter fichiers',
-'L_MEDIAS_DELETE_FOLDER'			=> 'Supprimer',
-'L_MEDIAS_DELETE_FOLDER_CONFIRM'	=> 'Supprimer le dossier %s et son contenu ?',
-'L_MEDIAS_FOLDER'					=> 'Dossier',
-'L_MEDIAS_NEW_FOLDER'				=> 'Nouveau dossier',
-'L_MEDIAS_CREATE_FOLDER'			=> 'Créer',
-'L_MEDIAS_FILESIZE'					=> 'Taille',
-'L_MEDIAS_DATE'						=> 'Date',
-'L_MEDIAS_DIMENSIONS'				=> 'Dimensions',
-'L_MEDIAS_NO_FILE'					=> 'Aucun fichier',
-'L_MEDIAS_RESIZE'					=> 'Redimensionner images',
-'L_MEDIAS_RESIZE_NO'				=> 'Taille originale',
-'L_MEDIAS_THUMBS'					=> 'Créer miniatures',
-'L_MEDIAS_THUMBS_NONE'				=> 'Pas de miniature',
-'L_MEDIAS_MODIFY'					=> 'Modifier',
-'L_MEDIAS_THUMB'					=> 'Miniature',
-'L_MEDIAS_EXTENSION'				=> 'Extension',
-'L_MEDIAS_ADD'						=> 'Ajouter',
-'L_MEDIAS_ALIGNMENT'				=> 'Alignement',
-'L_MEDIAS_ALIGN_NONE'				=> 'Aucun',
-'L_MEDIAS_ALIGN_LEFT'				=> 'Gauche',
-'L_MEDIAS_ALIGN_CENTER'				=> 'Centre',
-'L_MEDIAS_ALIGN_RIGHT'				=> 'Droite',
-'L_MEDIAS_RECREATE_THUMB'			=> 'Recréer miniatures',
+'L_MEDIAS_FILENAME'					=> 'Nazwa pliku',
+'L_MEDIAS_TITLE'					=> 'Zarządzanie mediami',
+'L_MEDIAS_DIRECTORY' 				=> 'lokalizacja',
+'L_MEDIAS_BACK'						=> 'Powrót do mediów',
+'L_MEDIAS_MAX_UPOLAD_FILE'			=> 'Maksymalny rozmiar pliku',
+'L_MEDIAS_MAX_POST_SIZE'			=> 'Maksymalny rozmiar danych',
+'L_MEDIAS_SUBMIT_FILE'				=> 'Wysłać',
+'L_MEDIAS_IMAGES'					=> 'Obrazowość',
+'L_MEDIAS_DOCUMENTS'				=> 'Dokumenty',
+'L_MEDIAS_ADD_FILE'					=> 'Dodawanie plików',
+'L_MEDIAS_DELETE_FOLDER'			=> 'Usunąć',
+'L_MEDIAS_DELETE_FOLDER_CONFIRM'	=> 'Usuń folder %s i jego zawartość ?',
+'L_MEDIAS_FOLDER'					=> 'Rekord',
+'L_MEDIAS_NEW_FOLDER'				=> 'Nowy folder',
+'L_MEDIAS_CREATE_FOLDER'			=> 'Tworzyć',
+'L_MEDIAS_FILESIZE'					=> 'Rozmiar',
+'L_MEDIAS_DATE'						=> 'Data',
+'L_MEDIAS_DIMENSIONS'				=> 'Wymiary',
+'L_MEDIAS_NO_FILE'					=> 'żaden plik',
+'L_MEDIAS_RESIZE'					=> 'Zmiana rozmiaru zdjęcia',
+'L_MEDIAS_RESIZE_NO'				=> 'Oryg',
+'L_MEDIAS_THUMBS'					=> 'Tworzenie miniaturek',
+'L_MEDIAS_THUMBS_NONE'				=> 'Nie miniatura',
+'L_MEDIAS_MODIFY'					=> 'Zmiana',
+'L_MEDIAS_THUMB'					=> 'Miniatura',
+'L_MEDIAS_EXTENSION'				=> 'Przedłużenie',
+'L_MEDIAS_ADD'						=> 'Dodać',
+'L_MEDIAS_ALIGNMENT'				=> 'Wyrównanie',
+'L_MEDIAS_ALIGN_NONE'				=> 'Nie',
+'L_MEDIAS_ALIGN_LEFT'				=> 'Lewo',
+'L_MEDIAS_ALIGN_CENTER'				=> 'Centrum',
+'L_MEDIAS_ALIGN_RIGHT'				=> 'Prawo',
+'L_MEDIAS_RECREATE_THUMB'			=> 'Odtworzyć miniatury',
+'L_MEDIAS_LINK_COPYCLP'             => 'Skopiuj link do schowka',
+'L_MEDIAS_LINK_COPYCLP_ERR'         => 'Nie można skopiować link do schowka',
+'L_MEDIAS_LINK_COPYCLP_DONE'        => 'Link został skopiowany',
+'L_MEDIAS_NEW_NAME'					=> 'Nowe imie',
+'L_MEDIAS_RENAME'					=> 'Przemianować',
 
 # parametres_affichage.php
 
@@ -326,6 +343,7 @@ $LANG = array(
 'L_CONFIG_VIEW_SORT'				=> 'Tri des articles',
 'L_CONFIG_VIEW_BYPAGE'				=> 'Nombre d\'articles affichés par page',
 'L_CONFIG_VIEW_BYPAGE_ARCHIVES'		=> 'Nombre d\'articles affichés par page dans les archives',
+'L_CONFIG_VIEW_BYPAGE_TAGS'			=> 'Artykuły na stronie w tagach',
 'L_CONFIG_VIEW_BYPAGE_ADMIN'		=> 'Nombre d\'articles affichés par page dans l\'administration',
 'L_CONFIG_VIEW_SORT_COMS'			=> 'Tri des commentaires',
 'L_CONFIG_VIEW_BYPAGE_ADMIN_COMS'	=> 'Nombre de commentaires affichés par page dans l\'administration',
@@ -410,7 +428,6 @@ $LANG = array(
 'L_CONFIG_USERS_UPDATE'				=> 'Modifier la liste des utilisateurs',
 'L_ERR_LOGIN_ALREADY_EXISTS'		=> 'Identifiant de connexion déjà utilisé',
 'L_ERR_USERNAME_ALREADY_EXISTS'		=> 'Nom d\'utilisateur déjà utilisé',
-'L_CONFIG_USERS_DELETE_CONFIRM'		=> 'Supprimer les utilisateurs sélectionnés ?',
 
 # parametre_plugins.php
 
@@ -434,6 +451,8 @@ $LANG = array(
 'L_PLUGINS_DELETE_SUCCESSFUL'		=> 'Suppression effectuée avec succès',
 'L_PLUGINS_CONFIG'					=> 'Configuration',
 'L_PLUGINS_CONFIG_TITLE'			=> 'Configuration du plugin',
+'L_PLUGINS_HELP'					=> 'Pomoc',
+'L_PLUGINS_HELP_TITLE'				=> 'Patrz Korzystanie z wtyczki',
 'L_PLUGINS_REQUIREMENTS'			=> 'Pré-requis',
 'L_PLUGINS_REQUIREMENTS_HELP'		=> 'Liste des plugins présents et actifs pour activer ce plugin',
 'L_PLUGINS_REQUIREMENTS_NONE'		=> 'Aucun',
@@ -499,7 +518,7 @@ $LANG = array(
 'L_PROFIL_MODERATOR'				=> 'Moderator',
 'L_PROFIL_EDITOR'					=> 'Edytor',
 'L_PROFIL_WRITER'					=> 'Redaktor',
-'L_ADMIN'							=> '- administracja',
+'L_ADMIN'							=> 'Administracja',
 'L_LOGIN'							=> 'Login',
 'L_ADMIN_LOGOUT'					=> 'Wyloguj',
 'L_ADMIN_LOGOUT_TITLE'				=> 'Opuść panel administracyjny',
@@ -523,7 +542,7 @@ $LANG = array(
 'L_MENU_CONFIG'						=> 'Ustawienia',
 'L_MENU_PROFIL_TITLE'				=> 'Zarządzaj profilami użytkowników',
 'L_MENU_PROFIL'						=> 'Profil',
-'L_WARNING_INSTALLATION_FILE'		=> 'Plik install.php znajduje się w katalogu głównym PluXml. <br />Ze względów bezpieczeństwa zaleca się, aby go usunąć.',
+'L_WARNING_INSTALLATION_FILE'		=> 'Plik install.php znajduje się w katalogu głównym PluXml. <br />Ze względów bezpieczeństwa zaleca się, aby go <a class="lnkdelete" href="?del=install">usunąć</a>.',
 
 # user.php
 'L_USER_UNKNOWN'					=> 'Nieznany użytkownik',
@@ -553,5 +572,6 @@ $LANG = array(
 'L_HELP'							=> 'Pomoc',
 'L_HELP_TITLE'						=> 'Zobacz pomoc',
 'L_BACK_TO_THEMES'					=> 'Powrót do tematów strony',
+'L_CONFIG_THEME_UPDATE'				=> 'Zmień styl',
 );
 ?>
