@@ -2,6 +2,7 @@
 
 $LANG = array(
 
+'L_ID' 														=> '#',
 'L_MENU'													=> 'Menu',
 'L_UNKNOWN_ERROR'											=> 'Erro desconhecido',
 'L_CONFIRM_DELETE'											=> 'Confirme a eliminação ?',
@@ -14,6 +15,11 @@ $LANG = array(
 'L_DELETE'													=> 'Excluir',
 'L_DELETE_FILE' 				    						=> 'Excluir arquivo',
 'L_DELETE_FOLDER'				   							=> 'Excluir pasta',
+'L_DELETE_SUCCESSFUL'										=> 'Apagado com sucesso',
+'L_DELETE_FILE_ERR'											=> 'Erro ao excluir o arquivo',
+'L_RENAME_FILE_SUCCESSFUL'									=> 'Arquivo renomeado com sucesso',
+'L_RENAME_FILE_ERR'											=> 'Erro ao processar o arquivo',
+'L_RENAME_FILE'												=> 'Renomear arquivo',
 'L_THUMBNAIL'												=> 'Miniatura (facultativo)',
 'L_THUMBNAIL_SELECTION'										=> 'Selecionar Imagem',
 'L_THUMBNAIL_TITLE'											=> 'Título de Imagem (facultativo)',
@@ -128,6 +134,7 @@ $LANG = array(
 'L_SUBMIT_BUTTON'											=> 'Validar',
 'L_ERR_WRONG_PASSWORD'										=> 'Login ou senha incorrecta',
 'L_POWERED_BY'												=> 'Propulsado por: <a href="http://www.pluxml.org">PluXml</a>',
+'L_ERR_MAXLOGIN'											=> 'Demasiados login falhou<br />Repetir em% s minutos',
 'L_CAT_TITLE'												=> 'Criação e edição das cetegorias',
 'L_CAT_LIST_ID'												=> 'Nome interno',
 'L_CAT_LIST_ACTIVE'											=> 'Activa',
@@ -221,14 +228,14 @@ $LANG = array(
 'L_ARTICLE_LIST_ACTION'										=> 'Ação',
 'L_CATEGORY_HOME'											=> 'Índice',
 'L_CATEGORY_DRAFT'											=> 'Brouillon',
-'L_ARTICLE_VIEW'											=> 'Visualizar',
 'L_ARTICLE_VIEW_TITLE'										=> 'Visualizar este artigo no web-site',
 'L_ARTICLE_EDIT'											=> 'Editar',
 'L_ARTICLE_EDIT_TITLE'										=> 'Editar este artigo',
 'L_NEW_COMMENTS_TITLE'										=> 'Comentários á espera de validação',
 'L_VALIDATED_COMMENTS_TITLE'								=> 'Comentários publicados',
 'L_NO_ARTICLE'												=> 'Nenhum artigo',
-'L_ARTICLES_SEARCH_BUTTON'									=> 'Pesquisa',
+'L_SEARCH'													=> 'Pesquisa',
+'L_SEARCH_PLACEHOLDER'										=> 'Identificante ou título',
 'L_ARTICLES_ALL_CATEGORIES'									=> 'Todas as categorias ...',
 'L_ALL'														=> 'Todos',
 'L_ALL_PUBLISHED'											=> 'Publicação',
@@ -246,6 +253,7 @@ $LANG = array(
 'L_MEDIAS_CREATE_FOLDER'									=> 'Criar uma pasta',
 'L_MEDIAS_SUBMIT_FILE'										=> 'Enviar',
 'L_MEDIAS_MAX_UPOLAD_FILE'									=> 'Tamanho máximo dos ficheiros',
+'L_MEDIAS_MAX_POST_SIZE'									=> 'Tamanho máximo de dados',
 'L_MEDIAS_DIRECTORY'										=> 'Localização',
 'L_MEDIAS_FOLDER'											=> 'Arquivo',
 'L_MEDIAS_NEW_FOLDER'										=> 'Nova Pasta',
@@ -266,9 +274,15 @@ $LANG = array(
 'L_MEDIAS_ALIGN_CENTER'										=> 'Centro',
 'L_MEDIAS_ALIGN_RIGHT'										=> 'Direito',
 'L_MEDIAS_RECREATE_THUMB'									=> 'Recriar de miniaturas',
+'L_MEDIAS_LINK_COPYCLP'                                     => 'Copy Link para área de transferência',
+'L_MEDIAS_LINK_COPYCLP_ERR'                                 => 'Não é possível copiar o link para a área de transferência',
+'L_MEDIAS_LINK_COPYCLP_DONE'                                => 'Link copiado',
+'L_MEDIAS_NEW_NAME'											=> 'Novo nome',
+'L_MEDIAS_RENAME'											=> 'Renomear',
 'L_SORT_ASCENDING_DATE'										=> 'data ascendente',
 'L_SORT_DESCENDING_DATE'									=> 'data decrescente',
 'L_SORT_ALPHABETICAL'										=> 'alfabético',
+'L_SORT_RANDOM'												=> 'aleatório',
 'L_OK'														=> 'Ok',
 'L_YES'														=> 'Sim',
 'L_NO'														=> 'Não',
@@ -281,6 +295,7 @@ $LANG = array(
 'L_CONFIG_VIEW_SORT'										=> 'Classificação dos artigos ',
 'L_CONFIG_VIEW_BYPAGE'										=> 'Numero de artigos mostrados / página',
 'L_CONFIG_VIEW_BYPAGE_ARCHIVES'								=> 'Numero de artigos mostrados / página nos arquivos',
+'L_CONFIG_VIEW_BYPAGE_TAGS'									=> 'Numero de artigos por página nas tags',
 'L_CONFIG_VIEW_BYPAGE_ADMIN'								=> 'Numero de artigos mostrados / página na administração',
 'L_CONFIG_VIEW_SORT_COMS'									=> 'Classificação dos comentários',
 'L_CONFIG_VIEW_BYPAGE_ADMIN_COMS'							=> 'Numero de comentários mostrados / página na administração',
@@ -369,6 +384,8 @@ $LANG = array(
 'L_PLUGINS_DELETE_SUCCESSFUL'								=> 'Supressão efectuada com sucesso',
 'L_PLUGINS_CONFIG'											=> 'Configuração',
 'L_PLUGINS_CONFIG_TITLE'									=> 'Configuração do plugin',
+'L_PLUGINS_HELP'											=> 'Ajudar',
+'L_PLUGINS_HELP_TITLE'										=> 'Consulte Usando o plugin',
 'L_PLUGINS_REQUIREMENTS'									=> 'Nacessário',
 'L_PLUGINS_REQUIREMENTS_HELP'								=> 'Lista dos plugins presentes e activos para activar este plugin',
 'L_PLUGINS_REQUIREMENTS_NONE'								=> 'Nenhum',
@@ -382,7 +399,7 @@ $LANG = array(
 'L_PROFIL'													=> 'Perfil',
 'L_PROFIL_LOGIN'											=> 'Login de conexão',
 'L_PROFIL_USER'												=> 'Nome do utilizador',
-'L_PROFIL_MAIL'												=> 'Enderêo e-mail',
+'L_PROFIL_MAIL'												=> 'Enderêco de e-mail',
 'L_PROFIL_ADMIN_LANG'										=> 'Idioma do utilizador na administração',
 'L_PROFIL_INFOS'											=> 'Informações',
 'L_PROFIL_UPDATE'											=> 'Alterar o seu perfil',
@@ -446,10 +463,10 @@ $LANG = array(
 'L_MENU_CONFIG'												=> 'Parâmetros',
 'L_MENU_PROFIL_TITLE'										=> 'Gerir o perfil do utilizador',
 'L_MENU_PROFIL'												=> 'Perfil',
-'L_WARNING_INSTALLATION_FILE'								=> 'O ficheiro install.php está presente na raíz de PluXml.<br />Por razões de segurança apague (delete) este ficheiro.',
+'L_WARNING_INSTALLATION_FILE'								=> 'O ficheiro install.php está presente na raíz de PluXml.<br />Por razões de segurança apague (<a class="lnkdelete" href="?del=install">delete</a>) este ficheiro.',
 'L_USER_UNKNOWN'											=> 'Utilizador desconhecido',
 'L_USER_LANG'												=> 'Idioma utilizado na administração',
-'L_USER_MAIL'												=> 'Enderêco e-mail',
+'L_USER_MAIL'												=> 'Enderêco de e-mail',
 'L_USER_INFOS'												=> 'Informações',
 'L_USER_UPDATE'												=> 'Actualizar este utilizador',
 'L_USER_PAGE_TITLE'											=> 'Edição das opções  do utilizador',
@@ -472,6 +489,7 @@ $LANG = array(
 'L_HELP'													=> 'Ajuda',
 'L_HELP_TITLE'												=> 'Vêr a ajuda',
 'L_BACK_TO_THEMES'											=> 'Voltar para os temas da página',
+'L_CONFIG_THEME_UPDATE'										=> 'Change Theme',
 'L_ERR_INVALID_DATE_CREATION'								=> 'Data de criação inválido',
 'L_ERR_INVALID_DATE_UPDATE'									=> 'Data inválida atualizado',
 );
