@@ -2,6 +2,7 @@
 
 $LANG = array(
 
+'L_ID' 														=> '#',
 'L_MENU'													=> 'Meniu',
 'L_UNKNOWN_ERROR'											=> 'Eroare necunoscută',
 'L_CONFIRM_DELETE'											=> 'Confirmați ștergerea ?',
@@ -14,6 +15,11 @@ $LANG = array(
 'L_DELETE'													=> 'Şterge',
 'L_DELETE_FILE' 				    						=> 'Ștergeți fișier',
 'L_DELETE_FOLDER'				   							=> 'Ștergeți dosar',
+'L_DELETE_SUCCESSFUL'										=> 'Stergere de succes',
+'L_DELETE_FILE_ERR'											=> 'Eroare la ștergerea fișierului',
+'L_RENAME_FILE_SUCCESSFUL'									=> 'Fișierul a fost redenumit cu succes',
+'L_RENAME_FILE_ERR'											=> 'Eroare în timpul procesării fișierului',
+'L_RENAME_FILE'												=> 'Redenumește fisierul',
 'L_THUMBNAIL'												=> 'Miniatură (opţional)',
 'L_THUMBNAIL_SELECTION'										=> 'Selectați Image',
 'L_THUMBNAIL_TITLE'											=> 'Titlu imagine (opţional)',
@@ -128,6 +134,7 @@ $LANG = array(
 'L_SUBMIT_BUTTON'											=> 'OK',
 'L_ERR_WRONG_PASSWORD'										=> 'Username sau parola incorecta',
 'L_POWERED_BY'												=> 'Realizat de <a href="http://www.pluxml.org">PluXml</a>',
+'L_ERR_MAXLOGIN'											=> 'Prea multe nu a reușit autentificare<br />Reîncercare în% s minute',
 'L_CAT_TITLE'												=> 'Crearea şi editarea categoriei',
 'L_CAT_LIST_ID'												=> 'Id',
 'L_CAT_LIST_ACTIVE'											=> 'Activ',
@@ -221,14 +228,14 @@ $LANG = array(
 'L_ARTICLE_LIST_ACTION'										=> 'Action',
 'L_CATEGORY_HOME'											=> 'Home',
 'L_CATEGORY_DRAFT'											=> 'Proiect de',
-'L_ARTICLE_VIEW'											=> 'Vizualizează',
 'L_ARTICLE_VIEW_TITLE'										=> 'Vezi acest articol pe site-ul',
 'L_ARTICLE_EDIT'											=> 'Editează',
 'L_ARTICLE_EDIT_TITLE'										=> 'Editează articolul dat',
 'L_NEW_COMMENTS_TITLE'										=> 'Comentarii ce aşteaptă validarea',
 'L_VALIDATED_COMMENTS_TITLE'								=> 'Comentarii postate',
 'L_NO_ARTICLE'												=> 'Nu sunt articole',
-'L_ARTICLES_SEARCH_BUTTON'									=> 'Căutare',
+'L_SEARCH'													=> 'Căutare',
+'L_SEARCH_PLACEHOLDER'										=> 'Identificator sau titlu',
 'L_ARTICLES_ALL_CATEGORIES'									=> 'Toate categoriile ...',
 'L_ALL'														=> 'Toate',
 'L_ALL_PUBLISHED'											=> 'Publicat',
@@ -246,6 +253,7 @@ $LANG = array(
 'L_MEDIAS_CREATE_FOLDER'									=> 'Crearea unui directoriu',
 'L_MEDIAS_SUBMIT_FILE'										=> 'Trimite',
 'L_MEDIAS_MAX_UPOLAD_FILE'									=> 'Dimensiunea maximă de fişier',
+'L_MEDIAS_MAX_POST_SIZE'									=> 'Dimensiunea maximă a datelor',
 'L_MEDIAS_DIRECTORY'										=> 'Locaţie',
 'L_MEDIAS_FOLDER'											=> 'Fişier',
 'L_MEDIAS_NEW_FOLDER'										=> 'New Folder',
@@ -266,9 +274,15 @@ $LANG = array(
 'L_MEDIAS_ALIGN_CENTER'										=> 'Centru',
 'L_MEDIAS_ALIGN_RIGHT'										=> 'Dreapta',
 'L_MEDIAS_RECREATE_THUMB'									=> 'Recreează miniatură',
+'L_MEDIAS_LINK_COPYCLP'                                     => 'Copiați linkul în clipboard',
+'L_MEDIAS_LINK_COPYCLP_ERR'                                 => 'Imposibil de copiat link-ul în clipboard',
+'L_MEDIAS_LINK_COPYCLP_DONE'                                => 'link-ul copiat',
+'L_MEDIAS_NEW_NAME'											=> 'Nume nou',
+'L_MEDIAS_RENAME'											=> 'Redenumire',
 'L_SORT_ASCENDING_DATE'										=> 'data crescator',
 'L_SORT_DESCENDING_DATE'									=> 'descendentă Data',
 'L_SORT_ALPHABETICAL'										=> 'alfabetic',
+'L_SORT_RANDOM'												=> 'aleatoriu',
 'L_OK'														=> 'Ok',
 'L_YES'														=> 'Da',
 'L_NO'														=> 'Nu',
@@ -279,8 +293,9 @@ $LANG = array(
 'L_CONFIG_VIEW_FILES_EDIT_TITLE'							=> 'Editaţi fişierele tema',
 'L_CONFIG_VIEW_FILES_EDIT'									=> 'Editaţi fişierele tema',
 'L_CONFIG_VIEW_SORT'										=> 'Sortare articole',
-'L_CONFIG_VIEW_BYPAGE'										=> 'Numărul de  articole afisate pe pagina',
-'L_CONFIG_VIEW_BYPAGE_ARCHIVES'								=> 'Numărul de  elemente afişate pe pagină în arhivă',
+'L_CONFIG_VIEW_BYPAGE'										=> 'Numărul de articole afisate pe pagina',
+'L_CONFIG_VIEW_BYPAGE_ARCHIVES'								=> 'Numărul de elemente afişate pe pagină în arhivă',
+'L_CONFIG_VIEW_BYPAGE_TAGS'									=> 'Numărul de articole pe pagină în etichetele',
 'L_CONFIG_VIEW_BYPAGE_ADMIN'								=> 'Numărul de  elemente afişate pe pagină în administraţie',
 'L_CONFIG_VIEW_SORT_COMS'									=> 'Sortare comentarii',
 'L_CONFIG_VIEW_BYPAGE_ADMIN_COMS'							=> 'Numărul de comentarii pe pagină în admin',
@@ -369,6 +384,8 @@ $LANG = array(
 'L_PLUGINS_DELETE_SUCCESSFUL'								=> 'Ştergerea a decurs cu succes',
 'L_PLUGINS_CONFIG'											=> 'Configurare',
 'L_PLUGINS_CONFIG_TITLE'									=> 'Configurarea plugin-ului',
+'L_PLUGINS_HELP'											=> 'Ajutor',
+'L_PLUGINS_HELP_TITLE'										=> 'A se vedea Utilizarea plugin-ului',
 'L_PLUGINS_REQUIREMENTS'									=> 'Cerinţe preliminare',
 'L_PLUGINS_REQUIREMENTS_HELP'								=> 'Lista de plugin-uri prezente şi active pentru activaţie',
 'L_PLUGINS_REQUIREMENTS_NONE'								=> 'Nu',
@@ -422,7 +439,7 @@ $LANG = array(
 'L_PROFIL_MODERATOR'										=> 'Moderator',
 'L_PROFIL_EDITOR'											=> 'Editor',
 'L_PROFIL_WRITER'											=> 'Autor',
-'L_ADMIN'													=> '- Administrare',
+'L_ADMIN'													=> 'Administrare',
 'L_LOGIN'													=> 'Logat ca',
 'L_ADMIN_LOGOUT'											=> 'Deconectare',
 'L_ADMIN_LOGOUT_TITLE'										=> 'Log Out Admin',
@@ -446,7 +463,7 @@ $LANG = array(
 'L_MENU_CONFIG'												=> 'Setări',
 'L_MENU_PROFIL_TITLE'										=> 'Gestionează profilul',
 'L_MENU_PROFIL'												=> 'Profil',
-'L_WARNING_INSTALLATION_FILE'								=> 'Fişierul install.php încă se află în rădăcina  sit-ului <br /> PluXml. Din motive de securitate, se recomandă să-l ştergeţi.',
+'L_WARNING_INSTALLATION_FILE'								=> 'Fişierul install.php încă se află în rădăcina  sit-ului <br /> PluXml. Din motive de securitate, se recomandă să-l <a class="lnkdelete" href="?del=install">ştergeţi</a>.',
 'L_USER_UNKNOWN'											=> 'Utilizator necunoscut',
 'L_USER_LANG'												=> 'Limba utilizată ',
 'L_USER_MAIL'												=> 'Adresa de email',
@@ -472,6 +489,7 @@ $LANG = array(
 'L_HELP'													=> 'Ajutor',
 'L_HELP_TITLE'												=> 'Vezi de ajutor',
 'L_BACK_TO_THEMES'											=> 'Înapoi la subiectele paginii',
+'L_CONFIG_THEME_UPDATE'										=> 'Înregistrarea temă',
 'L_ERR_INVALID_DATE_CREATION'								=> 'Data creării invalid',
 'L_ERR_INVALID_DATE_UPDATE'									=> 'Data invalid actualizat',
 );
