@@ -2,6 +2,7 @@
 
 $LANG = array(
 
+'L_ID' 														=> '#',
 'L_MENU'													=> 'меню',
 'L_UNKNOWN_ERROR'											=> 'Неизвестная ошибка',
 'L_CONFIRM_DELETE'											=> 'Подтвердите удаление ?',
@@ -14,6 +15,11 @@ $LANG = array(
 'L_DELETE'													=> 'Удалить',
 'L_DELETE_FILE' 				    						=> 'Удалить файл',
 'L_DELETE_FOLDER'				   							=> 'Удалить папку',
+'L_DELETE_SUCCESSFUL'										=> 'Успешное удаление',
+'L_DELETE_FILE_ERR'											=> 'Ошибка при удалении файла',
+'L_RENAME_FILE_SUCCESSFUL'									=> 'Файл успешно переименован',
+'L_RENAME_FILE_ERR'											=> 'Ошибка при обработке файла',
+'L_RENAME_FILE'												=> 'Переименуйте файл',
 'L_THUMBNAIL'												=> 'миниатюрами (необязательно)',
 'L_THUMBNAIL_SELECTION'										=> 'Выбрать Изображение',
 'L_THUMBNAIL_TITLE'											=> 'Изображение Название (необязательно)',
@@ -142,12 +148,14 @@ $LANG = array(
 'L_SUBMIT_BUTTON'											=> 'Войти',
 'L_ERR_WRONG_PASSWORD'										=> 'Неправильный логин или пароль',
 'L_POWERED_BY'												=> 'Powered by <a href="http://www.pluxml.org">PluXml</a>',
+'L_ERR_MAXLOGIN'											=> 'Слишком много неудачных Войти<br />Повторите попытку через% S минут',
 
 #
 
 'L_SORT_ASCENDING_DATE'										=> 'Дата по возрастанию',
 'L_SORT_DESCENDING_DATE'									=> 'Дата по убыванию',
 'L_SORT_ALPHABETICAL'										=> 'В алфавитном порядке',
+'L_SORT_RANDOM'												=> 'алеаторный',
 'L_YES'														=> 'Да',
 'L_NO'														=> 'Нет',
 'L_OK'														=> 'Ok',
@@ -260,7 +268,8 @@ $LANG = array(
 
 # index.php
 
-'L_ARTICLES_SEARCH_BUTTON'									=> 'Поиск',
+'L_SEARCH'													=> 'Поиск',
+'L_SEARCH_PLACEHOLDER'										=> 'ID или название',
 'L_ARTICLES_ALL_CATEGORIES'									=> 'Все категории ...',
 'L_ALL'														=> 'Всего',
 'L_ALL_PUBLISHED'											=> 'Опубликованные',
@@ -279,7 +288,6 @@ $LANG = array(
 'L_ARTICLE_LIST_ACTION'										=> 'Действие',
 'L_CATEGORY_HOME'											=> 'Главная',
 'L_CATEGORY_DRAFT'											=> 'Черновики',
-'L_ARTICLE_VIEW'											=> 'Открыть',
 'L_ARTICLE_VIEW_TITLE'										=> 'Открыть эту статью',
 'L_ARTICLE_EDIT'											=> 'Изменить',
 'L_ARTICLE_EDIT_TITLE'										=> 'Изменить эту статью',
@@ -294,6 +302,7 @@ $LANG = array(
 'L_MEDIAS_DIRECTORY'										=> 'Расположение',
 'L_MEDIAS_BACK'												=> 'Назад',
 'L_MEDIAS_MAX_UPOLAD_FILE'									=> 'Максимальный размер файла',
+'L_MEDIAS_MAX_POST_SIZE'									=> 'Максимальный размер данных',
 'L_MEDIAS_SUBMIT_FILE'										=> 'Загрузить',
 'L_MEDIAS_IMAGES'											=> 'Изображения',
 'L_MEDIAS_DOCUMENTS'										=> 'Документы',
@@ -321,6 +330,12 @@ $LANG = array(
 'L_MEDIAS_ALIGN_CENTER'										=> 'Центр',
 'L_MEDIAS_ALIGN_RIGHT'										=> 'Право',
 'L_MEDIAS_RECREATE_THUMB'									=> 'Обновить эскизы',
+'L_MEDIAS_LINK_COPYCLP'                                     => 'Скопировать ссылку в буфер обмена',
+'L_MEDIAS_LINK_COPYCLP_ERR'                                 => 'Невозможно скопировать ссылку в буфер обмена',
+'L_MEDIAS_LINK_COPYCLP_DONE'                                => 'ссылка скопирована',
+'L_MEDIAS_NEW_NAME'											=> 'Новое имя',
+'L_MEDIAS_RENAME'											=> 'Переименование',
+
 
 # parametres_affichage.php
 
@@ -331,6 +346,7 @@ $LANG = array(
 'L_CONFIG_VIEW_SORT'										=> 'Сортировка статей',
 'L_CONFIG_VIEW_BYPAGE'										=> 'Статей на странице',
 'L_CONFIG_VIEW_BYPAGE_ARCHIVES'								=> 'Статей на странице в архиве',
+'L_CONFIG_VIEW_BYPAGE_TAGS'									=> 'Статьи на странице в тегах',
 'L_CONFIG_VIEW_BYPAGE_ADMIN'								=> 'Статей на странице в Админке',
 'L_CONFIG_VIEW_SORT_COMS'									=> 'Сортировка комментариев',
 'L_CONFIG_VIEW_BYPAGE_ADMIN_COMS'							=> 'Комментариев на странице в админке',
@@ -438,6 +454,8 @@ $LANG = array(
 'L_PLUGINS_DELETE_SUCCESSFUL'								=> 'Удалено успешно',
 'L_PLUGINS_CONFIG'											=> 'Конфигурация',
 'L_PLUGINS_CONFIG_TITLE'									=> 'Конфигурация плагина',
+'L_PLUGINS_HELP'											=> 'помощь',
+'L_PLUGINS_HELP_TITLE'										=> 'Смотрите раздел Использование плагина',
 'L_PLUGINS_REQUIREMENTS'									=> 'Системные требования',
 'L_PLUGINS_REQUIREMENTS_HELP'								=> 'Доступные и активные плагины',
 'L_PLUGINS_REQUIREMENTS_NONE'								=> 'Нет',
@@ -503,7 +521,7 @@ $LANG = array(
 'L_PROFIL_MODERATOR'										=> 'Модератор',
 'L_PROFIL_EDITOR'											=> 'Редактор',
 'L_PROFIL_WRITER'											=> 'Автор',
-'L_ADMIN'													=> '- Администрирование',
+'L_ADMIN'													=> 'Администрирование',
 'L_LOGIN'													=> 'Вы зашли как',
 'L_ADMIN_LOGOUT'											=> 'Выйти',
 'L_ADMIN_LOGOUT_TITLE'										=> 'Завершить администрирование',
@@ -527,7 +545,7 @@ $LANG = array(
 'L_MENU_CONFIG'												=> 'Настройки',
 'L_MENU_PROFIL_TITLE'										=> 'Управление профилем пользователя',
 'L_MENU_PROFIL'												=> 'Профиль',
-'L_WARNING_INSTALLATION_FILE'								=> 'Внимание! Файл install.php все еще находится в корневой папке PluXml.<br />Из соображений безопасности настоятельно рекомендуем удалить его.',
+'L_WARNING_INSTALLATION_FILE'								=> 'Внимание! Файл install.php все еще находится в корневой папке PluXml.<br />Из соображений безопасности настоятельно рекомендуем <a class="lnkdelete" href="?del=install">удалить</a> его.',
 
 # user.php
 'L_USER_UNKNOWN'											=> 'Неизвестный пользователь',
@@ -557,5 +575,6 @@ $LANG = array(
 'L_HELP'													=> 'помощь',
 'L_HELP_TITLE'												=> 'См помощь',
 'L_BACK_TO_THEMES'											=> 'Вернуться к темам страницы',
+'L_CONFIG_THEME_UPDATE'										=> 'Изменить стиль',
 );
 ?>
\ No newline at end of file
