@@ -75,6 +75,8 @@ $LANG = array(
 'L_MODREWRITE_NOT_AVAILABLE'	=> 'Apache URL модуля mod_rewrite недоступен',
 'L_LIBGD_INSTALLED'				=> 'GD библиотека установлена',
 'L_LIBGD_NOT_INSTALLED'			=> 'GD библиотека не установлена',
+'L_LIBXML_INSTALLED'			=> 'XML библиотека установлена',
+'L_LIBXML_NOT_INSTALLED'		=> 'XML библиотека не установлена',
 'L_MAIL_AVAILABLE'				=> 'функция отправки почты доступна',
 'L_MAIL_NOT_AVAILABLE'			=> 'Функция отправки почты недоступна',
 
@@ -135,4 +137,4 @@ $LANG = array(
 'L_FEED_WRITTEN_BY'				=> 'Автор',
 
 );
-?>
\ No newline at end of file
+?>
