@@ -113,6 +113,9 @@ class plxAdmin extends plxMotor {
 		# On réinitialise la pagination au cas où modif de bypage_admin
 		unset($_SESSION['page']);
 
+		# On réactulise la langue
+		$_SESSION['lang'] = $global['default_lang'];
+
 		# Actions sur le fichier htaccess
 		if(isset($content['urlrewriting']))
 			if(!$this->htaccess($content['urlrewriting'], $global['racine']))
@@ -135,9 +138,6 @@ class plxAdmin extends plxMotor {
 			}
 		}
 
-		# changement de la langue en session
-		$_SESSION['lang'] = $global['default_lang'];
-
 		return plxMsg::Info(L_SAVE_SUCCESSFUL);
 
 	}
@@ -256,7 +256,7 @@ RewriteRule ^feed\/(.*)$ feed.php?$1 [L]
 		$this->aUsers[$_SESSION['user']]['email'] = trim($content['email']);
 		$this->aUsers[$_SESSION['user']]['lang'] = $content['lang'];
 
-		$_SESSION['lang'] = $content['lang'];
+		$_SESSION['admin_lang'] = $content['lang'];
 
 		# Hook plugins
 		if(eval($this->plxPlugins->callHook('plxAdminEditProfil'))) return;
@@ -293,7 +293,7 @@ RewriteRule ^feed\/(.*)$ feed.php?$1 [L]
 		$save = $this->aUsers;
 
 		# suppression
-		if(!empty($content['selection']) AND $content['selection']=='delete' AND isset($content['idUser'])) {
+		if(!empty($content['selection']) AND $content['selection']=='delete' AND isset($content['idUser']) AND empty($content['update'])) {
 			foreach($content['idUser'] as $user_id) {
 				if($content['selection']=='delete' AND $user_id!='001') {
 					$this->aUsers[$user_id]['delete']=1;
@@ -321,15 +321,20 @@ RewriteRule ^feed\/(.*)$ feed.php?$1 [L]
 						$password = $this->aUsers[$user_id]['password'];
 					}
 
+					# control de l'adresse email
+					$email = trim($content[$user_id.'_email']);
+					if($email!='' AND !plxUtils::checkMail($email))	return plxMsg::Error(L_ERR_INVALID_EMAIL);
+
 					$this->aUsers[$user_id]['login'] = trim($content[$user_id.'_login']);
 					$this->aUsers[$user_id]['name'] = trim($content[$user_id.'_name']);
 					$this->aUsers[$user_id]['active'] = ($_SESSION['user']==$user_id?$this->aUsers[$user_id]['active']:$content[$user_id.'_active']);
 					$this->aUsers[$user_id]['profil'] = ($_SESSION['user']==$user_id?$this->aUsers[$user_id]['profil']:$content[$user_id.'_profil']);
 					$this->aUsers[$user_id]['password'] = $password;
 					$this->aUsers[$user_id]['salt'] = $salt;
+					$this->aUsers[$user_id]['email'] = $email;
+
 					$this->aUsers[$user_id]['delete'] = (isset($this->aUsers[$user_id]['delete'])?$this->aUsers[$user_id]['delete']:0);
 					$this->aUsers[$user_id]['lang'] = (isset($this->aUsers[$user_id]['lang'])?$this->aUsers[$user_id]['lang']:$this->aConf['default_lang']);
-					$this->aUsers[$user_id]['email'] = (isset($this->aUsers[$user_id]['email'])?$this->aUsers[$user_id]['email']:'');
 					$this->aUsers[$user_id]['infos'] = (isset($this->aUsers[$user_id]['infos'])?$this->aUsers[$user_id]['infos']:'');
 					# Hook plugins
 					eval($this->plxPlugins->callHook('plxAdminEditUsersUpdate'));
@@ -437,7 +442,7 @@ RewriteRule ^feed\/(.*)$ feed.php?$1 [L]
 		$save = $this->aCats;
 
 		# suppression
-		if(!empty($content['selection']) AND $content['selection']=='delete' AND isset($content['idCategory'])) {
+		if(!empty($content['selection']) AND $content['selection']=='delete' AND isset($content['idCategory']) AND empty($content['update'])) {
 			foreach($content['idCategory'] as $cat_id) {
 				unset($this->aCats[$cat_id]);
 				$action = true;
@@ -570,7 +575,7 @@ RewriteRule ^feed\/(.*)$ feed.php?$1 [L]
 		$save = $this->aStats;
 
 		# suppression
-		if(!empty($content['selection']) AND $content['selection']=='delete' AND isset($content['idStatic'])) {
+		if(!empty($content['selection']) AND $content['selection']=='delete' AND isset($content['idStatic']) AND empty($content['update'])) {
 			foreach($content['idStatic'] as $static_id) {
 				$filename = PLX_ROOT.$this->aConf['racine_statiques'].$static_id.'.'.$this->aStats[$static_id]['url'].'.php';
 				if(is_file($filename)) unlink($filename);
@@ -767,6 +772,11 @@ RewriteRule ^feed\/(.*)$ feed.php?$1 [L]
 		# Hook plugins
 		if(eval($this->plxPlugins->callHook('plxAdminEditArticle'))) return;
 
+		# Suppression des doublons dans les tags
+		$tags = array_map('trim', explode(',', trim($content['tags'])));
+		$tags_unique = array_unique($tags);
+		$content['tags'] = implode(', ', $tags_unique);
+
 		# Formate des dates de creation et de mise à jour
 		$date_creation = $content['date_creation_year'].$content['date_creation_month'].$content['date_creation_day'].substr(str_replace(':','',$content['date_creation_time']),0,4);
 		$date_update = $content['date_update_year'].$content['date_update_month'].$content['date_update_day'].substr(str_replace(':','',$content['date_update_time']),0,4);
@@ -823,10 +833,9 @@ RewriteRule ^feed\/(.*)$ feed.php?$1 [L]
 			# mise à jour de la liste des tags
 			$this->aTags[$id] = array('tags'=>trim($content['tags']), 'date'=>$time, 'active'=>intval(!in_array('draft', $content['catId'])));
 			$this->editTags();
-			if($content['artId'] == '0000' OR $content['artId'] == '')
-				return plxMsg::Info(L_ARTICLE_SAVE_SUCCESSFUL);
-			else
-				return plxMsg::Info(L_ARTICLE_MODIFY_SUCCESSFUL);
+			$msg = ($content['artId'] == '0000' OR $content['artId'] == '') ? L_ARTICLE_SAVE_SUCCESSFUL : L_ARTICLE_MODIFY_SUCCESSFUL;
+			eval($this->plxPlugins->callHook('plxAdminEditArticleEnd'));
+			return plxMsg::Info($msg);
 		} else {
 			return plxMsg::Error(L_ARTICLE_SAVE_ERR);
 		}
@@ -916,7 +925,7 @@ RewriteRule ^feed\/(.*)$ feed.php?$1 [L]
 	public function editCommentaire($content, &$id) {
 
 		# Vérification de la validité de la date de publication
-		if(!plxDate::checkDate($content['day'],$content['month'],$content['year'],$content['time']))
+		if(!plxDate::checkDate($content['date_publication_day'],$content['date_publication_month'],$content['date_publication_year'],$content['date_publication_time']))
 			return plxMsg::Error(L_ERR_INVALID_PUBLISHING_DATE);
 
 		$comment=array();
@@ -932,20 +941,23 @@ RewriteRule ^feed\/(.*)$ feed.php?$1 [L]
 		# On récupère les infos du commentaire
 		$com = $this->parseCommentaire(PLX_ROOT.$this->aConf['racine_commentaires'].$comment['filename']);
 		# Formatage des données
-		$comment['author'] = plxUtils::strCheck(trim($content['author']));
-		$comment['site'] = plxUtils::strCheck(trim($content['site']));
-		if($com['type'] != 'admin')
+		if($com['type'] != 'admin') {
+			$comment['author'] = plxUtils::strCheck(trim($content['author']));
+			$comment['site'] = plxUtils::strCheck(trim($content['site']));
 			$comment['content'] = plxUtils::strCheck(trim($content['content']));
-		else
+		} else {
+			$comment['author'] = trim($content['author']);
+			$comment['site'] = trim($content['site']);
 			$comment['content'] = strip_tags(trim($content['content']),'<a>,<strong>');
+		}
 		$comment['ip'] = $com['ip'];
 		$comment['type'] = $com['type'];
 		$comment['mail'] = $content['mail'];
 		$comment['site'] = $content['site'];
 		$comment['parent'] = $com['parent'];
 		# Génération du nouveau nom du fichier
-		$time = explode(':', $content['time']);
-		$newtimestamp = mktime($time[0], $time[1], 0, $content['month'], $content['day'], $content['year']);
+		$time = explode(':', $content['date_publication_time']);
+		$newtimestamp = mktime($time[0], $time[1], 0, $content['date_publication_month'], $content['date_publication_day'], $content['date_publication_year']);
 		$com = $this->comInfoFromFilename($id.'.xml');
 		$newid = $com['comStatus'].$com['artId'].'.'.$newtimestamp.'-'.$com['comIdx'];
 		$comment['filename'] = $newid.'.xml';
@@ -1007,12 +1019,12 @@ RewriteRule ^feed\/(.*)$ feed.php?$1 [L]
 		@rename($oldfilename,$newfilename);
 		# Contrôle
 		if(is_readable($newfilename)) {
-			if($type == 'online')
+			if($mod == 'online')
 				return plxMsg::Info(L_COMMENT_VALIDATE_SUCCESSFUL);
 			else
 				return plxMsg::Info(L_COMMENT_MODERATE_SUCCESSFUL);
 		} else {
-			if($type == 'online')
+			if($mod == 'online')
 				return plxMsg::Error(L_COMMENT_VALIDATE_ERR);
 			else
 				return plxMsg::Error(L_COMMENT_MODERATE_ERR);
