@@ -34,8 +34,6 @@ class plxFeed extends plxMotor {
 
 		# On parse le fichier de configuration
 		$this->getConfiguration($filename);
-		# Chargement du fichier de langue
-		loadLang(PLX_CORE.'lang/'.$this->aConf['default_lang'].'/core.php');
 		# récupération des paramètres dans l'url
 		$this->get = plxUtils::getGets();
 		# gestion du timezone
@@ -273,7 +271,7 @@ class plxFeed extends plxMotor {
 		echo "\t".'<link>'.$link.'</link>'."\n";
 		echo "\t".'<language>' . $this->aConf['default_lang'] . '</language>'."\n";
 		echo "\t".'<description>'.plxUtils::strCheck($this->aConf['description']).'</description>'."\n";
-		echo '<atom:link xmlns:atom="http://www.w3.org/2005/Atom" rel="self" type="application/rss+xml" href="'.$this->urlRewrite('feed.php?'.$this->get).'" />'."\n";
+		echo "\t".'<atom:link xmlns:atom="http://www.w3.org/2005/Atom" rel="self" type="application/rss+xml" href="'.$this->urlRewrite('feed.php?'.$this->get).'" />'."\n";
 		$last_updated = plxDate::dateIso2rfc822($last_updated);
 		echo "\t".'<lastBuildDate>'.$last_updated.'</lastBuildDate>'."\n";
 		echo "\t".'<generator>PluXml</generator>'."\n";
@@ -313,12 +311,14 @@ class plxFeed extends plxMotor {
 						$title_com = $this->plxRecord_arts->f('title').' - ';
 						$title_com .= L_FEED_WRITTEN_BY.' '.$this->plxRecord_coms->f('author').' @ ';
 						$title_com .= plxDate::formatDate($this->plxRecord_coms->f('date'),'#day #num_day #month #num_year(4), #hour:#minute');
-						$link_com = $this->urlRewrite('?article'.$artId.'/'.$this->plxRecord_arts->f('url').'/#c'.$this->plxRecord_coms->f('numero'));
+						$comId = 'c'.$this->plxRecord_coms->f('article').'-'.$this->plxRecord_coms->f('index');
+						$link_com = $this->urlRewrite('?article'.$artId.'/'.$this->plxRecord_arts->f('url').'#'.$comId);
 					} else { # Commentaires globaux
 						$title_com = $this->plxRecord_coms->f('author').' @ ';
 						$title_com .= plxDate::formatDate($this->plxRecord_coms->f('date'),'#day #num_day #month #num_year(4), #hour:#minute');
 						$artInfo = $this->artInfoFromFilename($this->plxGlob_arts->aFiles[$this->plxRecord_coms->f('article')]);
-						$link_com = $this->urlRewrite('?article'.$artId.'/'.$artInfo['artUrl'].'#c'.$this->plxRecord_coms->f('numero'));
+						$comId = 'c'.$this->plxRecord_coms->f('article').'-'.$this->plxRecord_coms->f('index');
+						$link_com = $this->urlRewrite('?article'.$artId.'/'.$artInfo['artUrl'].'#'.$comId);
 					}
 					# On vérifie la date de publication
 					if($this->plxRecord_coms->f('date') > $last_updated)
@@ -344,9 +344,9 @@ class plxFeed extends plxMotor {
 		echo '<?xml version="1.0" encoding="'.PLX_CHARSET.'" ?>'."\n";
 		echo '<rss version="2.0" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:atom="http://www.w3.org/2005/Atom">'."\n";
 		echo '<channel>'."\n";
-		echo '<atom:link xmlns:atom="http://www.w3.org/2005/Atom" rel="self" type="application/rss+xml" href="' . $this->urlRewrite('feed.php?rss/commentaires/') . '" />'."\n";
+		echo "\t".'<atom:link xmlns:atom="http://www.w3.org/2005/Atom" rel="self" type="application/rss+xml" href="' . $this->urlRewrite('feed.php?rss/commentaires/') . '" />'."\n";
 
-		$entry .= "\t\t".'<title>'.strip_tags(html_entity_decode($title, ENT_QUOTES, PLX_CHARSET)).'</title> '."\n";
+		$entry .= "\t".'<title>'.strip_tags(html_entity_decode($title, ENT_QUOTES, PLX_CHARSET)).'</title> '."\n";
 		echo "\t".'<link>'.$link.'</link>'."\n";
 		echo "\t".'<language>' . $this->aConf['default_lang'] . '</language>'."\n";
 		echo "\t".'<description>'.plxUtils::strCheck($this->aConf['description']).'</description>'."\n";
@@ -413,7 +413,7 @@ class plxFeed extends plxMotor {
 		echo "\t".'<description>'.plxUtils::strCheck($this->aConf['description']).'</description>'."\n";
 		echo "\t".'<link>'.$link.'</link>'."\n";
 		echo "\t".'<language>' . $this->aConf['default_lang'] . '</language>'."\n";
-		echo '<atom:link xmlns:atom="http://www.w3.org/2005/Atom" rel="self" type="application/rss+xml" href="' . $link_feed . '" />'."\n";
+		echo "\t".'<atom:link xmlns:atom="http://www.w3.org/2005/Atom" rel="self" type="application/rss+xml" href="' . $link_feed . '" />'."\n";
 		$last_updated = plxDate::dateIso2rfc822($last_updated);
 		echo "\t".'<lastBuildDate>'.$last_updated.'</lastBuildDate>'."\n";
 		echo "\t".'<generator>PluXml</generator>'."\n";
