@@ -12,7 +12,8 @@ class plxMedias {
 	public $dir = null;
 	public $aDirs = array(); # liste des dossiers et sous dossiers
 	public $aFiles = array(); # liste des fichiers d'un dossier
-	public $maxUpload = array(); # taille maxi des images
+	public $maxUpload = array(); # valeur upload_max_filesize
+	public $maxPost = array(); # valeur post_max_size
 
 	public $thumbQuality = 60; # qualité image
 	public $thumbWidth = 60; # largeur des miniatures
@@ -48,7 +49,7 @@ class plxMedias {
 		$this->aDirs = $this->_getAllDirs($this->path);
 		$this->aFiles = $this->_getDirFiles($this->dir);
 
-		# Taille maxi pour l'upload de fichiers sur le serveur
+		# Taille maxi des fichiers
 		$maxUpload = strtoupper(ini_get("upload_max_filesize"));
 		$this->maxUpload['display'] = str_replace('M', ' Mo', $maxUpload);
 		$this->maxUpload['display'] = str_replace('K', ' Ko', $this->maxUpload['display']);
@@ -56,6 +57,16 @@ class plxMedias {
 		elseif(substr_count($maxUpload, 'M')) $this->maxUpload['value'] = str_replace('M', '', $maxUpload) * 1024 * 1024;
 		elseif(substr_count($maxUpload, 'G')) $this->maxUpload['value'] = str_replace('G', '', $maxUpload) * 1024 * 1024 * 1024;
 		else $this->maxUpload['value'] = 0;
+
+		# Taille maxi des données
+		$maxPost = strtoupper(ini_get("post_max_size"));
+		$this->maxPost['display'] = str_replace('M', ' Mo', $maxPost);
+		$this->maxPost['display'] = str_replace('K', ' Ko', $this->maxPost['display']);
+		if(substr_count($maxPost, 'K')) $this->maxPost['value'] = str_replace('K', '', $maxPost) * 1024;
+		elseif(substr_count($maxPost, 'M')) $this->maxPost['value'] = str_replace('M', '', $maxPost) * 1024 * 1024;
+		elseif(substr_count($maxPost, 'G')) $this->maxPost['value'] = str_replace('G', '', $maxPost) * 1024 * 1024 * 1024;
+		else $this->maxPost['value'] = 0;
+
 	}
 
 	/**
@@ -102,6 +113,8 @@ class plxMedias {
 	 **/
 	private function _getDirFiles($dir) {
 
+		if(!is_dir($this->path.$dir)) return array();
+
 		# Initialisation
 		$files = array();
 		# Ouverture et lecture du dossier demandé
@@ -111,8 +124,9 @@ class plxMedias {
 				if($file[0] != '.' AND !preg_match('/index.htm/i', $file) AND !preg_match('/^(.*\.)tb.([^.]+)$/D', $file)) {
 					if(is_file($this->path.$dir.$file)) {
 						$ext = strtolower(strrchr($this->path.$dir.$file,'.'));
+						$valid_ext = in_array($ext, array('.gif', '.jpg', '.jpeg', '.png'));
 						$_thumb1=file_exists($this->path.'.thumbs/'.$dir.$file);
-						if(!$_thumb1 AND in_array($ext, array('.gif', '.jpg', '.png'))) {
+						if(!$_thumb1 AND $valid_ext) {
 							$_thumb1 = plxUtils::makeThumb($this->path.$dir.$file, $this->path.'.thumbs/'.$dir.$file, $this->thumbWidth, $this->thumbHeight, $this->thumbQuality);
 						}
 						$_thumb2=false;
@@ -128,7 +142,7 @@ class plxMedias {
 							'path' 		=> $this->path.$dir.$file,
 							'date' 		=> filemtime($this->path.$dir.$file),
 							'filesize' 	=> filesize($this->path.$dir.$file),
-							'extension'	=> $ext,
+							'extension'	=> $valid_ext ? $ext : "",
 							'infos' 	=> getimagesize($this->path.$dir.$file),
 							'thumb' 	=> $_thumb2
 						);
@@ -297,7 +311,7 @@ class plxMedias {
 		# On teste l'existence du fichier et on formate le nom du fichier pour éviter les doublons
 		$i = 1;
 		$upFile = $this->path.$this->dir.plxUtils::title2filename($file['name']);
-		$name = substr($upFile, 0, strrpos($upFile,'.'));
+		$name = substr($file['name'], 0, strrpos($file['name'],'.'));
 		$ext = strrchr($upFile, '.');
 		while(file_exists($upFile)) {
 			$upFile = $this->path.$this->dir.$name.'.'.$i++.$ext;
@@ -449,7 +463,7 @@ class plxMedias {
 			if(is_file($this->path.$this->dir.$file)) {
 				$thumName = plxUtils::thumbName($file);
 				$ext = strtolower(strrchr($this->path.$this->dir.$file,'.'));
-				if(in_array($ext, array('.gif', '.jpg', '.png'))) {
+				if(in_array($ext, array('.gif', '.jpg', '.jpeg', '.png'))) {
 					if(plxUtils::makeThumb($this->path.$this->dir.$file, $this->path.$this->dir.$thumName, $width, $height, 80))
 						$count++;
 				}
@@ -470,5 +484,62 @@ class plxMedias {
 		}
 
 	}
+
+	/**
+	 * Méthode qui renomme un fichier
+	 *
+	 * @param   oldname		ancien nom
+	 * @param	newname		nouveau nom
+	 * @return  boolean		faux si erreur sinon vrai
+	 * @author	Stephane F
+	 **/
+	public function renameFile($oldname, $newname) {
+
+		$result = false;
+
+		$dirname = dirname($oldname)."/";
+		$filename = basename($oldname);
+		$ext = pathinfo($filename, PATHINFO_EXTENSION);
+
+		$newname = trim(basename($newname, pathinfo($newname, PATHINFO_EXTENSION)), '.');
+		$newname = $ext!="" ? $newname.'.'.$ext : $newname;
+
+		# Déplacement du fichier
+		if(is_readable($oldname) AND is_file($oldname)) {
+
+			# On teste l'existence du nouveau fichier et on formate le nom pour éviter les doublons
+			$i = 1;
+			$file = $dirname.plxUtils::title2filename($newname);
+			$name = substr($newname, 0, strrpos($newname,'.'));
+			while(file_exists($file)) {
+				$file = $dirname.$name.'.'.$i++.'.'.$ext;
+			}
+
+			# changement du nom du fichier
+			$result = rename($oldname, $file);
+
+			# changement du nom de la miniature
+			$old_thumbName = plxUtils::thumbName($oldname);
+			if($result AND is_readable($old_thumbName)) {
+				$new_thumbName = plxUtils::thumbName($file);
+				$result = rename($old_thumbName, $new_thumbName);
+			}
+
+			# changement du nom de la vignette
+			$path = str_replace($this->path, $this->path.'.thumbs/', $dirname);
+			$old_thumbName = $path.$filename;
+			if($result AND is_readable($old_thumbName)) {
+				$new_thumbName = $path.basename($file);
+				$result = rename($old_thumbName, $new_thumbName);
+			}
+
+		}
+
+		if($result)
+			return plxMsg::Info(L_RENAME_FILE_SUCCESSFUL);
+		else
+			return plxMsg::Error(L_RENAME_FILE_ERR);
+
+	}
 }
 ?>
