@@ -4,29 +4,29 @@
  * Classe plxMotor responsable du traitement global du script
  *
  * @package PLX
- * @author	Anthony GUÉRIN, Florent MONTHEL, Stéphane F
+ * @author	Anthony GURIN, Florent MONTHEL, Stphane F
  **/
 class plxMotor {
 
 	public $get = false; # Donnees variable GET
 	public $racine = false; # Url de PluXml
 	public $path_url = false; # chemin de l'url du site
-	public $style = false; # Dossier contenant le thème
+	public $style = false; # Dossier contenant le thme
 	public $tri; # Tri d'affichage des articles
 	public $tri_coms; # Tri d'affichage des commentaires
 	public $bypage = false; # Pagination des articles
-	public $page = 1; # Numéro de la page
+	public $page = 1; # Numro de la page
 	public $motif = false; # Motif de recherche
 	public $mode = false; # Mode de traitement
 	public $template = false; # Template d'affichage
 	public $cible = false; # Article, categorie ou page statique cible
 
 	public $activeCats = false; # Liste des categories actives sous la forme 001|002|003 etc
-	public $homepageCats = false; # Liste des categories à afficher sur la page d'accueil sous la forme 001|002|003 etc
-	public $activeArts = array(); # Tableaux des articles appartenant aux catégories actives
+	public $homepageCats = false; # Liste des categories  afficher sur la page d'accueil sous la forme 001|002|003 etc
+	public $activeArts = array(); # Tableaux des articles appartenant aux catgories actives
 
 	public $aConf = array(); # Tableau de configuration
-	public $aCats = array(); # Tableau de toutes les catégories
+	public $aCats = array(); # Tableau de toutes les catgories
 	public $aStats = array(); # Tableau de toutes les pages statiques
 	public $aTags = array(); # Tableau des tags
 	public $aUsers = array(); #Tableau des utilisateurs
@@ -42,7 +42,7 @@ class plxMotor {
 	private static $instance;
 
 	/**
-	 * Méthode qui se charger de créer le Singleton plxMotor
+	 * Mthode qui se charger de crer le Singleton plxMotor
 	 *
 	 * @return	objet			return une instance de la classe plxMotor
 	 * @author	Stephane F
@@ -61,21 +61,17 @@ class plxMotor {
 	 *
 	 * @param	filename	emplacement du fichier XML de configuration
 	 * @return	null
-	 * @author	Anthony GUÉRIN, Florent MONTHEL, Stéphane F
+	 * @author	Anthony GURIN, Florent MONTHEL, Stphane F
 	 **/
 	protected function __construct($filename) {
 
 		# On parse le fichier de configuration
 		$this->getConfiguration($filename);
-		# Chargement du fichier de langue
-		$lang = isset($_SESSION['lang']) ? $_SESSION['lang'] : $this->aConf['default_lang'];
-		$this->aConf['default_lang'] = $lang;
-		loadLang(PLX_CORE.'lang/'.$lang.'/core.php');
-		# récupération des paramètres dans l'url
+		# rcupration des paramtres dans l'url
 		$this->get = plxUtils::getGets();
 		# gestion du timezone
 		date_default_timezone_set($this->aConf['timezone']);
-		# On vérifie s'il faut faire une mise à jour
+		# On vrifie s'il faut faire une mise  jour
 		if((!isset($this->aConf['version']) OR PLX_VERSION!=$this->aConf['version']) AND !defined('PLX_UPDATER')) {
 			header('Location: '.PLX_ROOT.'update/index.php');
 			exit;
@@ -86,35 +82,39 @@ class plxMotor {
 		$this->bypage = $this->aConf['bypage'];
 		$this->tri = $this->aConf['tri'];
 		$this->tri_coms = $this->aConf['tri_coms'];
-		# On récupère le chemin de l'url
+		# On rcupre le chemin de l'url
 		$var = parse_url($this->racine);
 		$this->path_url = str_replace(ltrim($var['path'], '\/'), '', ltrim($_SERVER['REQUEST_URI'], '\/'));
 		# Traitement des plugins
+		# Dtermination du fichier de langue (nb: la langue peut tre modifie par plugins via $_SESSION['lang'])
+		$context = defined('PLX_ADMIN') ? 'admin_lang' : 'lang';
+		$lang = isset($_SESSION[$context]) ? $_SESSION[$context] : $this->aConf['default_lang'];
+		#--
 		$this->plxPlugins = new plxPlugins($lang);
 		$this->plxPlugins->loadPlugins();
 		# Hook plugins
 		eval($this->plxPlugins->callHook('plxMotorConstructLoadPlugins'));
-		# Traitement sur les répertoires des articles et des commentaires
+		# Traitement sur les rpertoires des articles et des commentaires
 		$this->plxGlob_arts = plxGlob::getInstance(PLX_ROOT.$this->aConf['racine_articles'],false,true,'arts');
 		$this->plxGlob_coms = plxGlob::getInstance(PLX_ROOT.$this->aConf['racine_commentaires']);
-		# Récupération des données dans les autres fichiers xml
+		# Rcupration des donnes dans les autres fichiers xml
 		$this->getCategories(path('XMLFILE_CATEGORIES'));
 		$this->getStatiques(path('XMLFILE_STATICS'));
 		$this->getTags(path('XMLFILE_TAGS'));
 		$this->getUsers(path('XMLFILE_USERS'));
-		# Récuperation des articles appartenant aux catégories actives
+		# Rcuperation des articles appartenant aux catgories actives
 		$this->getActiveArts();
 		# Hook plugins
 		eval($this->plxPlugins->callHook('plxMotorConstruct'));
 	}
 
 	/**
-	 * Méthode qui effectue une analyse de la situation et détermine
-	 * le mode à appliquer. Cette méthode alimente ensuite les variables
-	 * de classe adéquates
+	 * Mthode qui effectue une analyse de la situation et dtermine
+	 * le mode  appliquer. Cette mthode alimente ensuite les variables
+	 * de classe adquates
 	 *
 	 * @return	null
-	 * @author	Anthony GUÉRIN, Florent MONTHEL, Stéphane F
+	 * @author	Anthony GURIN, Florent MONTHEL, Stphane F
 	 **/
 	public function prechauffage() {
 
@@ -144,34 +144,28 @@ class plxMotor {
 			$this->motif = '/^'.$this->cible.'.((?:[0-9]|home|,)*(?:'.$this->activeCats.'|home)(?:[0-9]|home|,)*).[0-9]{3}.[0-9]{12}.[a-z0-9-]+.xml$/'; # Motif de recherche
 			if($this->getArticles()) {
 				# Redirection 301
-				if($this->plxRecord_arts->f('url')!=$capture[2]) {
-					header('Status: 301 Moved Permanently', false, 301);
-					header('Location: '.$this->urlRewrite('?article'.intval($this->cible).'/'.$this->plxRecord_arts->f('url')));
-					exit();
+				if(!isset($capture[2]) OR $this->plxRecord_arts->f('url')!=$capture[2]) {
+					$this->redir301($this->urlRewrite('?article'.intval($this->cible).'/'.$this->plxRecord_arts->f('url')));
 				}
 			} else {
 				$this->error404(L_UNKNOWN_ARTICLE);
 			}
 		}
 		elseif($this->get AND preg_match('/^static([0-9]+)\/?([a-z0-9-]+)?/',$this->get,$capture)) {
-			$this->cible = str_pad($capture[1],3,'0',STR_PAD_LEFT); # On complète sur 3 caractères
+			$this->cible = str_pad($capture[1],3,'0',STR_PAD_LEFT); # On complte sur 3 caractres
 			if(!isset($this->aStats[$this->cible]) OR !$this->aStats[$this->cible]['active']) {
 				$this->error404(L_UNKNOWN_STATIC);
 			} else {
 				if(!empty($this->aConf['homestatic']) AND $capture[1]){
 					if($this->aConf['homestatic']==$this->cible){
-						header('Status: 301 Moved Permanently', false, 301);
-						header('Location: '.$this->urlRewrite());
-						exit();
+						$this->redir301($this->urlRewrite());
 					}
 				}
 				if($this->aStats[$this->cible]['url']==$capture[2]) {
 					$this->mode = 'static'; # Mode static
 					$this->template = $this->aStats[$this->cible]['template'];
 				} else {
-					header('Status: 301 Moved Permanently', false, 301);
-					header('Location: '.$this->urlRewrite('?static'.intval($this->cible).'/'.$this->aStats[$this->cible]['url']));
-					exit();
+					$this->redir301($this->urlRewrite('?static'.intval($this->cible).'/'.$this->aStats[$this->cible]['url']));
 				}
 			}
 		}
@@ -186,9 +180,7 @@ class plxMotor {
 			}
 			elseif(isset($this->aCats[$this->cible])) { # Redirection 301
 				if($this->aCats[$this->cible]['url']!=$capture[2]) {
-					header('Status: 301 Moved Permanently', false, 301);
-					header('Location: '.$this->urlRewrite('?categorie'.intval($this->cible).'/'.$this->aCats[$this->cible]['url']));
-					exit();
+					$this->redir301($this->urlRewrite('?categorie'.intval($this->cible).'/'.$this->aCats[$this->cible]['url']));
 				}
 			} else {
 				$this->error404(L_UNKNOWN_CATEGORY);
@@ -226,7 +218,7 @@ class plxMotor {
 				$this->mode = 'tags'; # Affichage en mode home
 				$this->template = 'tags.php';
 				$this->motif = '/('.implode('|', $ids).').(?:[0-9]|home|,)*(?:'.$this->activeCats.'|home)(?:[0-9]|home|,)*.[0-9]{3}.[0-9]{12}.[a-z0-9-]+.xml$/';
-				$this->bypage = $this->aConf['bypage']; # Nombre d'article par page
+				$this->bypage = $this->aConf['bypage_tags']; # Nombre d'article par page
 			} else {
 				$this->error404(L_ARTICLE_NO_TAG);
 			}
@@ -251,7 +243,22 @@ class plxMotor {
 	}
 
 	/**
-	 * Méthode qui retourne une erreur 404 Document non trouvé
+	 * Mthode qui fait une redirection de type 301
+	 *
+	 * @return	null
+	 * @author	Stephane F
+	 **/
+	public function redir301($url) {
+		# Hook plugins
+		eval($this->plxPlugins->callHook('plxMotorRedir301'));
+		# Redirection 301
+		header('Status: 301 Moved Permanently', false, 301);
+		header('Location: '.$url);
+		exit();
+	}
+
+	/**
+	 * Mthode qui retourne une erreur 404 Document non trouv
 	 *
 	 * @return	null
 	 * @author	Stephane F
@@ -265,7 +272,7 @@ class plxMotor {
 	}
 
 	/**
-	 * Méthode qui effectue le traitement selon le mode du moteur
+	 * Mthode qui effectue le traitement selon le mode du moteur
 	 *
 	 * @return	null
 	 * @author	Florent MONTHEL, Stephane F
@@ -276,23 +283,23 @@ class plxMotor {
 		if(eval($this->plxPlugins->callHook('plxMotorDemarrageBegin'))) return;
 
 		if($this->mode == 'home' OR $this->mode == 'categorie' OR $this->mode == 'archives' OR $this->mode == 'tags') {
-			$this->getPage(); # Recuperation du numéro de la page courante
+			$this->getPage(); # Recuperation du numro de la page courante
 			if(!$this->getArticles()) { # Si aucun article
 				$this->error404(L_NO_ARTICLE_PAGE);
 			}
 		}
 		elseif($this->mode == 'article') {
 
-			# On a validé le formulaire commentaire
+			# On a valid le formulaire commentaire
 			if(!empty($_POST) AND $this->plxRecord_arts->f('allow_com') AND $this->aConf['allow_com']) {
-				# On récupère le retour de la création
+				# On rcupre le retour de la cration
 				$retour = $this->newCommentaire($this->cible,plxUtils::unSlash($_POST));
 				# Url de l'article
 				$url = $this->urlRewrite('?article'.intval($this->plxRecord_arts->f('numero')).'/'.$this->plxRecord_arts->f('url'));
 				eval($this->plxPlugins->callHook('plxMotorDemarrageNewCommentaire'));
-				if($retour[0] == 'c') { # Le commentaire a été publié
+				if($retour[0] == 'c') { # Le commentaire a t publi
 					header('Location: '.$url.'#'.$retour);
-				} elseif($retour == 'mod') { # Le commentaire est en modération
+				} elseif($retour == 'mod') { # Le commentaire est en modration
 					$_SESSION['msgcom'] = L_COM_IN_MODERATION;
 					header('Location: '.$url.'#form');
 				} else {
@@ -307,16 +314,16 @@ class plxMotor {
 				}
 				exit;
 			}
-			# Récupération des commentaires
+			# Rcupration des commentaires
 			$this->getCommentaires('/^'.$this->cible.'.[0-9]{10}-[0-9]+.xml$/',$this->mapTri($this->tri_coms));
 			$this->template=$this->plxRecord_arts->f('template');
-			if($this->aConf['capcha']) $this->plxCapcha = new plxCapcha(); # Création objet captcha
+			if($this->aConf['capcha']) $this->plxCapcha = new plxCapcha(); # Cration objet captcha
 		}
 		elseif($this->mode == 'preview') {
 			$this->mode='article';
 			$this->plxRecord_arts = new plxRecord($_SESSION['preview']);
 			$this->template=$this->plxRecord_arts->f('template');
-			if($this->aConf['capcha']) $this->plxCapcha = new plxCapcha(); # Création objet captcha
+			if($this->aConf['capcha']) $this->plxCapcha = new plxCapcha(); # Cration objet captcha
 		}
 
 		# Hook plugins
@@ -324,12 +331,12 @@ class plxMotor {
 	}
 
 	/**
-	 * Méthode qui parse le fichier de configuration et alimente
+	 * Mthode qui parse le fichier de configuration et alimente
 	 * le tableau aConf
 	 *
 	 * @param	filename	emplacement du fichier XML de configuration
 	 * @return	null
-	 * @author	Anthony GUÉRIN, Florent MONTHEL, Stéphane F
+	 * @author	Anthony GURIN, Florent MONTHEL, Stphane F
 	 **/
 	public function getConfiguration($filename) {
 
@@ -352,13 +359,14 @@ class plxMotor {
 					$this->aConf[ $values[ $iTags['parametre'][$i] ]['attributes']['name'] ] = '';
 			}
 		}
-		# détermination automatique de la racine du site
+		# dtermination automatique de la racine du site
 		$this->aConf['racine'] = plxUtils::getRacine();
-		# On gère la non régression en cas d'ajout de paramètres sur une version de pluxml déjà installée
+		# On gre la non rgression en cas d'ajout de paramtres sur une version de pluxml dj installe
 		$this->aConf['bypage_admin'] = plxUtils::getValue($this->aConf['bypage_admin'],10);
 		$this->aConf['tri_coms'] = plxUtils::getValue($this->aConf['tri_coms'],$this->aConf['tri']);
 		$this->aConf['bypage_admin_coms'] = plxUtils::getValue($this->aConf['bypage_admin_coms'],10);
 		$this->aConf['bypage_archives'] = plxUtils::getValue($this->aConf['bypage_archives'],5);
+		$this->aConf['bypage_tags'] = plxUtils::getValue($this->aConf['bypage_tags'],5);
 		$this->aConf['userfolders'] = plxUtils::getValue($this->aConf['userfolders'],0);
 		$this->aConf['meta_description'] = plxUtils::getValue($this->aConf['meta_description']);
 		$this->aConf['meta_keywords'] = plxUtils::getValue($this->aConf['meta_keywords']);
@@ -377,12 +385,12 @@ class plxMotor {
 	}
 
 	/**
-	 * Méthode qui parse le fichier des catégories et alimente
+	 * Mthode qui parse le fichier des catgories et alimente
 	 * le tableau aCats
 	 *
-	 * @param	filename	emplacement du fichier XML des catégories
+	 * @param	filename	emplacement du fichier XML des catgories
 	 * @return	null
-	 * @author	Stéphane F
+	 * @author	Stphane F
 	 **/
 	public function getCategories($filename) {
 
@@ -404,7 +412,7 @@ class plxMotor {
 			for($i=0;$i<$nb;$i++) {
 				$attributes = $values[$iTags['categorie'][$i*$size]]['attributes'];
 				$number = $attributes['number'];
-				# Recuperation du nom de la catégorie
+				# Recuperation du nom de la catgorie
 				$this->aCats[$number]['name']=plxUtils::getValue($values[$iTags['name'][$i]]['value']);
 				# Recuperation du nom de la description
 				$this->aCats[$number]['description']=plxUtils::getValue($values[$iTags['description'][$i]]['value']);
@@ -425,9 +433,9 @@ class plxMotor {
 				$this->aCats[$number]['bypage']=isset($attributes['bypage'])?$attributes['bypage']:$this->bypage;
 				# Recuperation du fichier template
 				$this->aCats[$number]['template']=isset($attributes['template'])?$attributes['template']:'categorie.php';
-				# Récuperation état affichage de la catégorie dans le menu
+				# Rcuperation tat affichage de la catgorie dans le menu
 				$this->aCats[$number]['menu']=isset($attributes['menu'])?$attributes['menu']:'oui';
-				# Récuperation état activation de la catégorie dans le menu
+				# Rcuperation tat activation de la catgorie dans le menu
 				$this->aCats[$number]['active']=isset($attributes['active'])?$attributes['active']:'1';
 				if($this->aCats[$number]['active']) $activeCats[]=$number;
 				# Recuperation affichage en page d'accueil
@@ -442,19 +450,19 @@ class plxMotor {
 				eval($this->plxPlugins->callHook('plxMotorGetCategories'));
 			}
 		}
-		$homepageCats [] = '000'; # on rajoute la catégorie 'Non classée'
-		$activeCats[] = '000'; # on rajoute la catégorie 'Non classée'
+		$homepageCats [] = '000'; # on rajoute la catgorie 'Non classe'
+		$activeCats[] = '000'; # on rajoute la catgorie 'Non classe'
 		$this->homepageCats = implode('|', $homepageCats);
 		$this->activeCats = implode('|', $activeCats);
 	}
 
 	/**
-	 * Méthode qui parse le fichier des pages statiques et alimente
+	 * Mthode qui parse le fichier des pages statiques et alimente
 	 * le tableau aStats
 	 *
 	 * @param	filename	emplacement du fichier XML des pages statiques
 	 * @return	null
-	 * @author	Stéphane F
+	 * @author	Stphane F
 	 **/
 	public function getStatiques($filename) {
 
@@ -473,31 +481,31 @@ class plxMotor {
 			for($i=0;$i<$nb;$i++) {
 				$attributes = $values[$iTags['statique'][$i*$size]]['attributes'];
 				$number = $attributes['number'];
-				# Récupération du nom de la page statique
+				# Rcupration du nom de la page statique
 				$this->aStats[$number]['name']=plxUtils::getValue($values[$iTags['name'][$i]]['value']);
-				# Récupération de la balise title
+				# Rcupration de la balise title
 				$title_htmltag = plxUtils::getValue($iTags['title_htmltag'][$i]);
 				$this->aStats[$number]['title_htmltag']=plxUtils::getValue($values[$title_htmltag]['value']);
-				# Récupération du meta description
+				# Rcupration du meta description
 				$meta_description = plxUtils::getValue($iTags['meta_description'][$i]);
 				$this->aStats[$number]['meta_description']=plxUtils::getValue($values[$meta_description]['value']);
-				# Récupération du meta keywords
+				# Rcupration du meta keywords
 				$meta_keywords = plxUtils::getValue($iTags['meta_keywords'][$i]);
 				$this->aStats[$number]['meta_keywords']=plxUtils::getValue($values[$meta_keywords]['value']);
-				# Récupération du groupe de la page statique
+				# Rcupration du groupe de la page statique
 				$this->aStats[$number]['group']=plxUtils::getValue($values[$iTags['group'][$i]]['value']);
-				# Récupération de l'url de la page statique
+				# Rcupration de l'url de la page statique
 				$this->aStats[$number]['url']=strtolower($attributes['url']);
-				# Récupération de l'etat de la page
+				# Rcupration de l'etat de la page
 				$this->aStats[$number]['active']=intval($attributes['active']);
 				# On affiche la page statique dans le menu ?
 				$this->aStats[$number]['menu']=isset($attributes['menu'])?$attributes['menu']:'oui';
-				# Récupération du fichier template
+				# Rcupration du fichier template
 				$this->aStats[$number]['template']=isset($attributes['template'])?$attributes['template']:'static.php';
-				# Récupération de la date de création
+				# Rcupration de la date de cration
 				$date_creation = plxUtils::getValue($iTags['date_creation'][$i]);
 				$this->aStats[$number]['date_creation']=plxUtils::getValue($values[$date_creation]['value']);
-				# Récupération de la date de mise à jour
+				# Rcupration de la date de mise  jour
 				$date_update = plxUtils::getValue($iTags['date_update'][$i]);
 				$this->aStats[$number]['date_update']=plxUtils::getValue($values[$date_update]['value']);
 				# On verifie que la page statique existe bien
@@ -511,7 +519,7 @@ class plxMotor {
 	}
 
 	/**
-	 * Méthode qui parse le fichier des utilisateurs
+	 * Mthode qui parse le fichier des utilisateurs
 	 *
 	 * @param	filename	emplacement du fichier XML des passwd
 	 * @return	array		tableau des utilisateurs
@@ -555,11 +563,11 @@ class plxMotor {
 	}
 
 	/**
-	 * Méthode qui selon le paramètre tri retourne sort ou rsort (tri PHP)
+	 * Mthode qui selon le paramtre tri retourne sort ou rsort (tri PHP)
 	 *
 	 * @param	tri	asc ou desc
 	 * @return	string
-	 * @author	Stéphane F.
+	 * @author	Stphane F.
 	 **/
 	protected function mapTri($tri) {
 
@@ -569,16 +577,18 @@ class plxMotor {
 			return 'sort';
 		elseif($tri=='alpha')
 			return 'alpha';
+		elseif($tri=='random')
+			return 'random';
 		else
 			return 'rsort';
 
 	}
 
 	/**
-	 * Méthode qui récupère le numéro de la page active
+	 * Mthode qui rcupre le numro de la page active
 	 *
 	 * @return	null
-	 * @author	Anthony GUÉRIN, Florent MONTHEL, Stephane F
+	 * @author	Anthony GURIN, Florent MONTHEL, Stephane F
 	 **/
 	protected function getPage() {
 
@@ -590,11 +600,11 @@ class plxMotor {
 	}
 
 	/**
-	 * Méthode qui récupere la liste des  articles
+	 * Mthode qui rcupere la liste des  articles
 	 *
-	 * @param	publi	before, after ou all => on récupère tous les fichiers (date) ?
-	 * @return	boolean	vrai si articles trouvés, sinon faux
-	 * @author	Stéphane F
+	 * @param	publi	before, after ou all => on rcupre tous les fichiers (date) ?
+	 * @return	boolean	vrai si articles trouvs, sinon faux
+	 * @author	Stphane F
 	 **/
 	public function getArticles($publi='before') {
 
@@ -604,7 +614,7 @@ class plxMotor {
 		$start = $this->bypage*($this->page-1);
 		# On recupere nos fichiers (tries) selon le motif, la pagination, la date de publication
 		if($aFiles = $this->plxGlob_arts->query($this->motif,'art',$ordre,$start,$this->bypage,$publi)) {
-			# on mémorise le nombre total d'articles trouvés
+			# on mmorise le nombre total d'articles trouvs
 			foreach($aFiles as $k=>$v) # On parcourt tous les fichiers
 				$array[$k] = $this->parseArticle(PLX_ROOT.$this->aConf['racine_articles'].$v);
 			# On stocke les enregistrements dans un objet plxRecord
@@ -615,11 +625,11 @@ class plxMotor {
 	}
 
 	/**
-	 * Méthode qui retourne les informations $output en analysant
+	 * Mthode qui retourne les informations $output en analysant
 	 * le nom du fichier de l'article $filename
 	 *
-	 * @param	filename	fichier de l'article à traiter
-	 * @return	array		information à récupérer
+	 * @param	filename	fichier de l'article  traiter
+	 * @return	array		information  rcuprer
 	 * @author	Stephane F
 	 **/
 	public function artInfoFromFilename($filename) {
@@ -637,11 +647,11 @@ class plxMotor {
 	}
 
 	/**
-	 * Méthode qui parse l'article du fichier $filename
+	 * Mthode qui parse l'article du fichier $filename
 	 *
-	 * @param	filename	fichier de l'article à parser
+	 * @param	filename	fichier de l'article  parser
 	 * @return	array
-	 * @author	Anthony GUÉRIN, Florent MONTHEL, Stéphane F
+	 * @author	Anthony GURIN, Florent MONTHEL, Stphane F
 	 **/
 	public function parseArticle($filename) {
 
@@ -685,10 +695,10 @@ class plxMotor {
 	}
 
 	/**
-	 * Méthode qui retourne le nombre de commentaires respectants le motif $motif et le paramètre $publi
+	 * Mthode qui retourne le nombre de commentaires respectants le motif $motif et le paramtre $publi
 	 *
 	 * @param	motif	motif de recherche des commentaires
-	 * @param	publi	before, after ou all => on récupère tous les fichiers (date) ?
+	 * @param	publi	before, after ou all => on rcupre tous les fichiers (date) ?
 	 * @return	integer
 	 * @author	Florent MONTHEL
 	 **/
@@ -701,11 +711,11 @@ class plxMotor {
 	}
 
 	/**
-	 * Méthode qui retourne les informations $output en analysant
+	 * Mthode qui retourne les informations $output en analysant
 	 * le nom du fichier du commentaire $filename
 	 *
-	 * @param	filename	fichier du commentaire à traiter
-	 * @return	array		information à récupérer
+	 * @param	filename	fichier du commentaire  traiter
+	 * @return	array		information  rcuprer
 	 * @author	Stephane F
 	 **/
 	public function comInfoFromFilename($filename) {
@@ -724,9 +734,9 @@ class plxMotor {
 	}
 
 	/**
-	 * Méthode qui parse le commentaire du fichier $filename
+	 * Mthode qui parse le commentaire du fichier $filename
 	 *
-	 * @param	filename	fichier du commentaire à parser
+	 * @param	filename	fichier du commentaire  parser
 	 * @return	array
 	 * @author	Florent MONTHEL
 	 **/
@@ -764,10 +774,10 @@ class plxMotor {
 	}
 
 	/**
-	 * Méthode qui trie récursivement les commentaires d'un article en fonction des parents
+	 * Mthode qui trie rcursivement les commentaires d'un article en fonction des parents
 	 *
-	 * @return	array	liste des commentaires triés
-	 * @author	Stéphane F.
+	 * @return	array	liste des commentaires tris
+	 * @author	Stphane F.
 	 **/
 	public function parentChildSort_r($idField, $parentField, $els, $parentID = 0, &$result = array(), &$level = 0){
 		foreach ($els as $key => $value) {
@@ -787,26 +797,26 @@ class plxMotor {
 	}
 
 	/**
-	 * Méthode qui enregistre dans un objet plxRecord tous les commentaires
+	 * Mthode qui enregistre dans un objet plxRecord tous les commentaires
 	 * respectant le motif $motif et la limite $limite
 	 *
 	 * @param	motif	motif de recherche des commentaires
 	 * @param	ordre	ordre du tri : sort ou rsort
 	 * @param	start	commencement
-	 * @param	limite	nombre de commentaires à retourner
-	 * @param	publi	before, after ou all => on récupère tous les fichiers (date) ?
+	 * @param	limite	nombre de commentaires  retourner
+	 * @param	publi	before, after ou all => on rcupre tous les fichiers (date) ?
 	 * @return	null
 	 * @author	Florent MONTHEL, Stephane F
 	 **/
 	public function getCommentaires($motif,$ordre='sort',$start=0,$limite=false,$publi='before') {
 
-		# On récupère les fichiers des commentaires
+		# On rcupre les fichiers des commentaires
 		$aFiles = $this->plxGlob_coms->query($motif,'com',$ordre,$start,$limite,$publi);
 		if($aFiles) { # On a des fichiers
 			foreach($aFiles as $k=>$v)
 				$array[$k] = $this->parseCommentaire(PLX_ROOT.$this->aConf['racine_commentaires'].$v);
 
-			# hiérarchisation et indentation des commentaires seulement sur les écrans requis
+			# hirarchisation et indentation des commentaires seulement sur les crans requis
 			if( !(defined('PLX_ADMIN') OR defined('PLX_FEED')) OR preg_match('/comment_new/',basename($_SERVER['SCRIPT_NAME']))) {
 				$array = $this->parentChildSort_r('index', 'parent', $array);
 			}
@@ -820,7 +830,7 @@ class plxMotor {
 	}
 
 	/**
-	 *  Méthode qui retourne le prochain id d'un commentaire pour un article précis
+	 *  Mthode qui retourne le prochain id d'un commentaire pour un article prcis
 	 *
 	 * @param	idArt		id de l'article
 	 * @return	string		id d'un nouveau commentaire
@@ -843,72 +853,72 @@ class plxMotor {
 	}
 
 	/**
-	 * Méthode qui crée un nouveau commentaire pour l'article $artId
+	 * Mthode qui cre un nouveau commentaire pour l'article $artId
 	 *
 	 * @param	artId	identifiant de l'article en question
 	 * @param	content	tableau contenant les valeurs du nouveau commentaire
 	 * @return	string
-	 * @author	Florent MONTHEL, Stéphane F
+	 * @author	Florent MONTHEL, Stphane F
 	 **/
 	public function newCommentaire($artId,$content) {
 
 		# Hook plugins
 		if(eval($this->plxPlugins->callHook('plxMotorNewCommentaire'))) return;
 
-		if(strtolower($_SERVER['REQUEST_METHOD'])!= 'post' OR !isset($_SESSION["capcha_token"]) OR !isset($_POST['capcha_token']) OR ($_SESSION["capcha_token"]!=$_POST['capcha_token'])) {
+		if(strtolower($_SERVER['REQUEST_METHOD'])!= 'post' OR $this->aConf['capcha'] AND (!isset($_SESSION["capcha_token"]) OR !isset($_POST['capcha_token']) OR ($_SESSION["capcha_token"]!=$_POST['capcha_token']))) {
 			return L_NEWCOMMENT_ERR_ANTISPAM;
 		}
 
-		# On vérifie que le capcha est correct
+		# On vrifie que le capcha est correct
 		if($this->aConf['capcha'] == 0 OR $_SESSION['capcha'] == sha1($content['rep'])) {
 			if(!empty($content['name']) AND !empty($content['content'])) { # Les champs obligatoires sont remplis
 				$comment=array();
 				$comment['type'] = 'normal';
 				$comment['author'] = plxUtils::strCheck(trim($content['name']));
 				$comment['content'] = plxUtils::strCheck(trim($content['content']));
-				# On vérifie le mail
+				# On vrifie le mail
 				$comment['mail'] = (plxUtils::checkMail(trim($content['mail'])))?trim($content['mail']):'';
-				# On vérifie le site
+				# On vrifie le site
 				$comment['site'] = (plxUtils::checkSite($content['site'])?$content['site']:'');
-				# On récupère l'adresse IP du posteur
+				# On rcupre l'adresse IP du posteur
 				$comment['ip'] = plxUtils::getIp();
 				# index du commentaire
-				$idx = $this->nextIdArtComment($idArt);
-				# Commentaire parent en cas de réponse
+				$idx = $this->nextIdArtComment($artId);
+				# Commentaire parent en cas de rponse
 				if(isset($content['parent']) AND !empty($content['parent'])) {
 					$comment['parent'] = intval($content['parent']);
 				} else {
 					$comment['parent'] = '';
 				}
-				# On génère le nom du fichier
+				# On gnre le nom du fichier
 				$time = time();
-				if($this->aConf['mod_com']) # On modère le commentaire => underscore
+				if($this->aConf['mod_com']) # On modre le commentaire => underscore
 					$comment['filename'] = '_'.$artId.'.'.$time.'-'.$idx.'.xml';
 				else # On publie le commentaire directement
 					$comment['filename'] = $artId.'.'.$time.'-'.$idx.'.xml';
-				# On peut créer le commentaire
+				# On peut crer le commentaire
 				if($this->addCommentaire($comment)) { # Commentaire OK
-					if($this->aConf['mod_com']) # En cours de modération
+					if($this->aConf['mod_com']) # En cours de modration
 						return 'mod';
 					else # Commentaire publie directement, on retourne son identifiant
 						return 'c'.$artId.'-'.$idx;
-				} else { # Erreur lors de la création du commentaire
+				} else { # Erreur lors de la cration du commentaire
 					return L_NEWCOMMENT_ERR;
 				}
 			} else { # Erreur de remplissage des champs obligatoires
 				return L_NEWCOMMENT_FIELDS_REQUIRED;
 			}
-		} else { # Erreur de vérification capcha
+		} else { # Erreur de vrification capcha
 			return L_NEWCOMMENT_ERR_ANTISPAM;
 		}
 	}
 
 	/**
-	 * Méthode qui crée physiquement le fichier XML du commentaire
+	 * Mthode qui cre physiquement le fichier XML du commentaire
 	 *
-	 * @param	comment	array avec les données du commentaire à ajouter
-	 * @return	booléen
-	 * @author	Anthony GUÉRIN, Florent MONTHEL et Stéphane F
+	 * @param	comment	array avec les donnes du commentaire  ajouter
+	 * @return	boolen
+	 * @author	Anthony GURIN, Florent MONTHEL et Stphane F
 	 **/
 	public function addCommentaire($content) {
 		# Hook plugins
@@ -931,7 +941,7 @@ class plxMotor {
 	}
 
 	/**
-	 * Méthode qui parse le fichier des tags et alimente
+	 * Mthode qui parse le fichier des tags et alimente
 	 * le tableau aTags
 	 *
 	 * @param	filename	emplacement du fichier XML contenant les tags
@@ -964,25 +974,25 @@ class plxMotor {
 				$array[ $values[ $iTags['article'][$i] ]['attributes']['number'] ]['active'] = $values[ $iTags['article'][$i] ]['attributes']['active'];
 			}
 		}
-		# Mémorisation de la liste des tags
+		# Mmorisation de la liste des tags
 		$this->aTags = $array;
 	}
 
 	/**
-	 * Méthode qui lance le téléchargement d'un document
+	 * Mthode qui lance le tlchargement d'un document
 	 *
-	 * @param	cible	cible de téléchargement cryptée
+	 * @param	cible	cible de tlchargement crypte
 	 * @return	booleen
 	 * @author	Stephane F. et Florent MONTHEL
 	 **/
 	public function sendTelechargement($cible) {
 
-		# On décrypte le nom du fichier
-		$file = PLX_ROOT.$this->aConf['documents'].plxEncrypt::decryptId($cible);
+		# On dcrypte le nom du fichier
+		$file = PLX_ROOT.$this->aConf['medias'].plxEncrypt::decryptId($cible);
 		# Hook plugins
 		if(eval($this->plxPlugins->callHook('plxMotorSendDownload'))) return;
-		# On lance le téléchargement et on check le répertoire documents
-		if(file_exists($file) AND preg_match('#^'.str_replace('\\', '/', realpath(PLX_ROOT.$this->aConf['documents']).'#'), str_replace('\\', '/', realpath($file)))) {
+		# On lance le tlchargement et on check le rpertoire medias
+		if(file_exists($file) AND preg_match('#^'.str_replace('\\', '/', realpath(PLX_ROOT.$this->aConf['medias']).'#'), str_replace('\\', '/', realpath($file)))) {
 			header('Content-Description: File Transfer');
 			header('Content-Type: application/download');
 			header('Content-Disposition: attachment; filename='.basename($file));
@@ -1000,11 +1010,11 @@ class plxMotor {
 	}
 
 	/**
-	 * Méthode qui réécrit les urls pour supprimer le ?
+	 * Mthode qui rcrit les urls pour supprimer le ?
 	 *
-	 * @param	url		url à réécrire
-	 * @return	string	url réécrite
-	 * @author	Stéphane F
+	 * @param	url		url  rcrire
+	 * @return	string	url rcrite
+	 * @author	Stphane F
 	 **/
 	public function urlRewrite($url='') {
 
@@ -1029,10 +1039,10 @@ class plxMotor {
 	}
 
 	/**
-	 * Méthode qui comptabilise le nombre d'articles du site.
+	 * Mthode qui comptabilise le nombre d'articles du site.
 	 *
-	 * @param	select	critere de recherche: draft, published, all, n° categories séparés par un |
-	 * @param	userid	filtre sur les articles d'un utilisateur donné
+	 * @param	select	critere de recherche: draft, published, all, n categories spars par un |
+	 * @param	userid	filtre sur les articles d'un utilisateur donn
 	 * @param	mod		filtre sur les articles en attente de validation
 	 * @param	publi	selection en fonciton de la date du jour (all, before, after)
 	 * @return	integer	nombre d'articles
@@ -1058,10 +1068,10 @@ class plxMotor {
 	}
 
 	/**
-	 * Méthode qui comptabilise le nombre de commentaires du site
+	 * Mthode qui comptabilise le nombre de commentaires du site
 	 *
 	 * @param	select	critere de recherche des commentaires: all, online, offline
-	 * @param	publi	type de sélection des commentaires: all, before, after
+	 * @param	publi	type de slection des commentaires: all, before, after
 	 * @return	integer	nombre de commentaires
 	 * @scope	global
 	 * @author	Stephane F
@@ -1085,18 +1095,18 @@ class plxMotor {
 	}
 
 	/**
-	 * Méthode qui recherche les articles appartenant aux catégories actives
+	 * Mthode qui recherche les articles appartenant aux catgories actives
 	 *
 	 * @return	null
 	 * @scope	global
-	 * @author	Stéphane F.
+	 * @author	Stphane F.
 	 **/
 	public function getActiveArts() {
 		if($this->plxGlob_arts->aFiles) {
 			$datetime=date('YmdHi');
 			foreach($this->plxGlob_arts->aFiles as $filename) {
 				if(preg_match('/^([0-9]{4}).(?:[0-9]|home|,)*(?:'.$this->activeCats.'|home)(?:[0-9]|home|,)*.[0-9]{3}.([0-9]{12}).[a-z0-9-]+.xml$/', $filename, $capture)) {
-					if($capture[2]<=$datetime) { # on ne prends que les articles publiés
+					if($capture[2]<=$datetime) { # on ne prends que les articles publis
 						$this->activeArts[$capture[1]]=1;
 					}
 				}
