@@ -35,7 +35,11 @@ class plxPlugins {
 		if(is_file($filename)) {
 			include_once($filename);
 			if (class_exists($plugName)) {
-				return new $plugName($this->default_lang);
+				# réactualisation de la langue si elle a été modifié par un plugin
+				$context = defined('PLX_ADMIN') ? 'admin_lang' : 'lang';
+				$lang = isset($_SESSION[$context]) ? $_SESSION[$context] : $this->default_lang;
+				# chargement du plugin en créant une nouvelle instance
+				return new $plugName($lang);
 			}
 		}
 		return false;
@@ -50,6 +54,9 @@ class plxPlugins {
 	public function loadPlugins() {
 
 		if(!is_file(path('XMLFILE_PLUGINS'))) return;
+
+		$updAction = false;
+
 		# Mise en place du parseur XML
 		$data = implode('',file(path('XMLFILE_PLUGINS')));
 		$parser = xml_parser_create(PLX_CHARSET);
@@ -67,9 +74,25 @@ class plxPlugins {
 				if($instance=$this->getInstance($name)) {
 					$this->aPlugins[$name] = $instance;
 					$this->aHooks = array_merge_recursive($this->aHooks, $instance->getHooks());
+					# Si le plugin a une méthode pour des actions de mises à jour
+					if(method_exists($instance, 'onUpdate')) {
+						if(is_file(PLX_PLUGINS.$name.'/update')) {
+							# on supprime le fichier update pour eviter d'appeler la methode onUpdate
+							# à chaque chargement du plugin
+							unlink(PLX_PLUGINS.$name.'/update');
+							$updAction = $instance->onUpdate();
+						}
+					}
 				}
 			}
 		}
+
+		if($updAction) {
+			if(isset($updAction['cssCache']) AND $updAction['cssCache']==true) {
+				$this->cssCache('admin');
+				$this->cssCache('site');
+			}
+		}
 	}
 
 	/**
@@ -141,7 +164,7 @@ class plxPlugins {
 	public function saveConfig($content) {
 
 		# activation des plugins
-		if(isset($content['selection']) AND $content['selection']=='activate') {
+		if(isset($content['selection']) AND $content['selection']=='activate' AND empty($content['update'])) {
 			foreach($content['chkAction'] as $idx => $plugName) {
 				if($plugInstance = $this->getInstance($plugName)) {
 					if(method_exists($plugName, 'OnActivate'))
@@ -151,7 +174,7 @@ class plxPlugins {
 			}
 		}
 		# désactivation des plugins
-		elseif(isset($content['selection']) AND $content['selection']=='deactivate') {
+		elseif(isset($content['selection']) AND $content['selection']=='deactivate' AND empty($content['update'])) {
 			foreach($content['chkAction'] as $idx => $plugName) {
 				if($plugInstance = $this->aPlugins[$plugName]) {
 					if(method_exists($plugName, 'OnDeActivate'))
@@ -161,7 +184,7 @@ class plxPlugins {
 			}
 		}
 		# suppression des plugins
-		elseif(isset($content['selection']) AND $content['selection']=='delete') {
+		elseif(isset($content['selection']) AND $content['selection']=='delete' AND empty($content['update'])) {
 			foreach($content['chkAction'] as $idx => $plugName) {
 				if($this->deleteDir(realpath(PLX_PLUGINS.$plugName))) {
 					# suppression fichier de config du plugin
@@ -238,6 +261,7 @@ class plxPlugins {
 	 * @author	Stephane F
 	 **/
 	public function cssCache($type) {
+
 		$cache = '';
 		foreach($this->aPlugins as $plugName => $plugInstance) {
 			$filename = PLX_ROOT.PLX_CONFIG_PATH.'plugins/'.$plugName.'.'.$type.'.css';
@@ -287,8 +311,9 @@ class plxPlugin {
 	 * @author	Stephane F
 	 **/
 	public function __construct($default_lang='') {
-		$this->default_lang = $default_lang;
+
 		$plugName= get_class($this);
+		$this->getPluginLang($plugName, $default_lang);
 		$this->plug = array(
 			'dir' 			=> PLX_PLUGINS,
 			'name' 			=> $plugName,
@@ -296,10 +321,49 @@ class plxPlugin {
 			'parameters.xml'=> PLX_ROOT.PLX_CONFIG_PATH.'plugins/'.$plugName.'.xml',
 			'infos.xml'		=> PLX_PLUGINS.$plugName.'/infos.xml'
 		);
-		$this->aLang = $this->loadLang(PLX_PLUGINS.$plugName.'/lang/'.$this->default_lang.'.php');
 		$this->loadParams();
 		if(defined('PLX_ADMIN'))
 			$this->getInfos();
+
+	}
+
+	/**
+	 * Méthode qui charge le fichier de langue du plugin
+	 * Si la langue par défaut n'est pas disponible on tente de charger le fr.php sinon on prend le 1er fichier de langue dispo
+	 *
+	 * @param	default_lang	langue par défaut utilisée par PluXml
+	 * @return	null
+	 * @author	Stephane F
+	 **/
+
+	public function getPluginLang($plugName, $lang) {
+
+		$dirname = PLX_PLUGINS.$plugName.'/lang/';
+
+		if(is_dir($dirname)) {
+
+			$filename = $dirname.$lang.'.php';
+
+			if(!is_file($filename)) {
+				if(is_file($dirname.'fr.php'))
+					$lang = 'fr';
+				else {
+					if($dh = opendir($dirname)) {
+						while(false !== ($file = readdir($dh))) {
+							if(preg_match('/^([a-zA-Z]{2})\.php$/', $file, $capture)) {
+								$lang = $capture[1];
+								break;
+							}
+						}
+					}
+					closedir($dh);
+				}
+			}
+		}
+
+		$this->default_lang = $lang;
+		$this->aLang = $this->loadLang(PLX_PLUGINS.$plugName.'/lang/'.$this->default_lang.'.php');
+
 	}
 
 	/**
@@ -610,7 +674,7 @@ class plxPlugin {
 	public function REL_PATH() {
 		return PLX_PLUGINS.get_class($this).'/';
 	}
-	
+
 	/**
 	 * Méthode qui retourne le chemin absolu du dossier du plugin
 	 *
