@@ -40,10 +40,12 @@ class plxShow {
 		$langfile = PLX_ROOT.$this->plxMotor->aConf['racine_themes'].$this->plxMotor->style.'/lang/'.$this->plxMotor->aConf['default_lang'].'.php';
 		if(is_file($langfile)) {
 			include($langfile);
-			$this->lang = $LANG;
+			$this->lang = $LANG; # $LANG = tableau contenant les traductions présentes dans le fichier de langue
 		}
+
 		# Hook Plugins
 		eval($this->plxMotor->plxPlugins->callHook('plxShowConstruct'));
+
 	}
 
 	/**
@@ -86,15 +88,18 @@ class plxShow {
 	}
 
 	/**
-	 * Méthode qui retourne le mode d'affichage
+	 * Méthode qui affiche ou retourne le mode d'affichage
 	 *
+	 * @param   echo 	si à VRAI affichage écran (à FAUX par défaut pour gérer la non régression PluXml < 5.6)
 	 * @return	string	mode d'affichage (home, article, categorie, static ou erreur)
 	 * @scope	global
 	 * @author	Stephane F.
 	 **/
-	public function mode() {
-
-		return $this->plxMotor->mode;
+	public function mode($echo=false) {
+		if($echo)
+			echo $this->plxMotor->mode;
+		else
+			return $this->plxMotor->mode;
 	}
 
 	/**
@@ -329,7 +334,7 @@ class plxShow {
 	 * position.
 	 *
 	 * @param	extra	nom du lien vers la page d'accueil
-	 * @param	format	format du texte pour chaque catégorie (variable : #cat_id, #cat_status, #cat_url, #cat_name, #art_nb)
+	 * @param	format	format du texte pour chaque catégorie (variable : #cat_id, #cat_status, #cat_url, #cat_name, #cat_description, #art_nb)
 	 * @param	include	liste des catégories à afficher séparées par le caractère | (exemple: 001|003)
 	 * @param	exclude	liste des catégories à ne pas afficher séparées par le caractère | (exemple: 002|003)
 	 * @return	stdout
@@ -361,6 +366,7 @@ class plxShow {
 						$name = str_replace('#cat_url',$this->plxMotor->urlRewrite('?categorie'.intval($k).'/'.$v['url']),$name);
 						$name = str_replace('#cat_name',plxUtils::strCheck($v['name']),$name);
 						$name = str_replace('#cat_status',($this->catId()==intval($k)?'active':'noactive'), $name);
+						$name = str_replace('#cat_description',plxUtils::strCheck($v['description']),$name);
 						$name = str_replace('#art_nb',$v['articles'],$name);
 						echo $name;
 					}
@@ -477,19 +483,24 @@ class plxShow {
 	}
 
 	/**
-	 * Méthode qui affiche l'url de l'article de type relatif ou absolu
+	 * Méthode qui affiche ou retourne l'url de l'article
 	 *
-	 * @param	type (deprecated)	type de lien : relatif ou absolu
+	 * @param	echo 	si à VRAI affichage à l'écran
+	 * @param 	extra 	paramètres supplémentaires pouvant être rajoutés à la fin de l'url de l'atricle
 	 * @return	stdout
 	 * @scope	home,categorie,article,tags,archives
 	 * @author	Florent MONTHEL, Stephane F
 	 **/
-	public function artUrl($type='') {
+	public function artUrl($echo=true, $extra='') {
 
 		# On affiche l'URL
 		$id = intval($this->plxMotor->plxRecord_arts->f('numero'));
-		$url = $this->plxMotor->plxRecord_arts->f('url');
-		echo $this->plxMotor->urlRewrite('?article'.$id.'/'.$url);
+		$url = $this->plxMotor->urlRewrite('?article'.$id.'/'.$this->plxMotor->plxRecord_arts->f('url').$extra);
+		if($echo)
+			echo $url;
+		else
+			return $url;
+
 	}
 
 	/**
@@ -542,7 +553,7 @@ class plxShow {
 	/**
 	 * Méthode qui affiche ou renvoie l'auteur de l'article
 	 *
-	 * @param echo si à VRAI affichage à l'écran
+	 * @param 	echo si à VRAI affichage à l'écran
 	 * @return	stdout
 	 * @scope	home,categorie,article,tags,archives
 	 * @author	Anthony GUÉRIN, Florent MONTHEL et Stephane F
@@ -838,10 +849,6 @@ class plxShow {
 	 **/
 	public function artNbCom($f1='L_NO_COMMENT',$f2='#nb L_COMMENT',$f3='#nb L_COMMENTS') {
 
-		# A t'on besoin d'afficher le nb de commentaires ?
-		if(!$this->plxMotor->aConf['allow_com'] OR !$this->plxMotor->plxRecord_arts->f('allow_com'))
-			return;
-
 		$nb = intval($this->plxMotor->plxRecord_arts->f('nb_com'));
 		$num = intval($this->plxMotor->plxRecord_arts->f('numero'));
 		$url = $this->plxMotor->plxRecord_arts->f('url');
@@ -1030,15 +1037,16 @@ class plxShow {
 	/**
 	 * Méthode qui formate et affiche le niveau d'indentation du commentaire
 	 *
+	 * @param	class	nom de la classe css servant à l'indentation des commentaires
 	 * @return	stdout
 	 * @scope	article
-	 * @author	Stephane F.
+	 * @author	Stephane F., Jerry Wham
 	 **/
-	public function comLevel() {
+	public function comLevel($class='level') {
 		if($this->comNumLevel() > 5)
-			echo 'level-'.$this->comNumLevel().' level-max';
+			echo $class.'-'.$this->comNumLevel().' '.$class.'-max';
 		else
-			echo 'level-'.$this->comNumLevel();
+			echo $class.'-'.$this->comNumLevel();
 	}
 
 	/**
@@ -1265,13 +1273,13 @@ class plxShow {
 	 *
 	 * @param	extra			si renseigné: nom du lien vers la page d'accueil affiché en première position
 	 * @param	format			format du texte pour chaque page (variable : #static_id, #static_status, #static_url, #static_name, #group_id, #group_class, #group_name)
-	 * @param	format_group	format du texte pour chaque groupe (variable : #group_class, #group_name)
+	 * @param	format_group	format du texte pour chaque groupe (variable : #group_class, #group_name, #group_status)
 	 * @param	menublog		position du menu Blog (si non renseigné le menu n'est pas affiché)
 	 * @return	stdout
 	 * @scope	global
 	 * @author	Stephane F
 	 **/
-	public function staticList($extra='', $format='<li id="#static_id" class="#static_class"><a href="#static_url" class="#static_status" title="#static_name">#static_name</a></li>', $format_group='<span class="#group_class">#group_name</span>', $menublog=false) {
+	public function staticList($extra='', $format='<li class="#static_class #static_status" id="#static_id" ><a href="#static_url" title="#static_name">#static_name</a></li>', $format_group='<span class="#group_class #group_status">#group_name</span>', $menublog=false) {
 
 		$menus = array();
 		# Hook Plugins
@@ -1280,17 +1288,18 @@ class plxShow {
 		# Si on a la variable extra, on affiche un lien vers la page d'accueil (avec $extra comme nom)
 		if($extra != '') {
 			$stat = str_replace('#static_id','static-home',$format);
-			$stat = str_replace('#static_class','static-group',$stat);
+			$stat = str_replace('#static_class','static menu',$stat);
 			$stat = str_replace('#static_url',$this->plxMotor->urlRewrite(),$stat);
 			$stat = str_replace('#static_name',plxUtils::strCheck($extra),$stat);
 			$stat = str_replace('#static_status',($home==true?"active":"noactive"), $stat);
 			$menus[][] = $stat;
 		}
+		$group_active = "";
 		if($this->plxMotor->aStats) {
 			foreach($this->plxMotor->aStats as $k=>$v) {
 				if($v['active'] == 1 AND $v['menu'] == 'oui') { # La page  est bien active et dispo ds le menu
 					$stat = str_replace('#static_id','static-'.intval($k),$format);
-					$stat = str_replace('#static_class','static-menu',$stat);
+					$stat = str_replace('#static_class','static menu',$stat);
 					if($v['url'][0]=='?') # url interne commençant par ?
 						$stat = str_replace('#static_url',$this->plxMotor->urlRewrite($v['url']),$stat);
 					elseif(plxUtils::checkSite($v['url'],false)) # url externe en http ou autre
@@ -1298,26 +1307,28 @@ class plxShow {
 					else # url page statique
 						$stat = str_replace('#static_url',$this->plxMotor->urlRewrite('?static'.intval($k).'/'.$v['url']),$stat);
 					$stat = str_replace('#static_name',plxUtils::strCheck($v['name']),$stat);
-					$stat = str_replace('#static_status',(($home===false AND $this->staticId()==intval($k))?'static active':'noactive'), $stat);
+					$stat = str_replace('#static_status',($this->staticId()==intval($k)?'active':'noactive'), $stat);
 					if($v['group']=='')
 						$menus[][] =  $stat;
 					else
 						$menus[$v['group']][] =  $stat;
+					if($group_active=="" AND $home===false AND $this->staticId()==intval($k) AND $v['group']!='')
+						$group_active = $v['group'];
 				}
 			}
 		}
 		if($menublog) {
 			if($this->plxMotor->aConf['homestatic']!='' AND isset($this->plxMotor->aStats[$this->plxMotor->aConf['homestatic']])) {
 				if($this->plxMotor->aStats[$this->plxMotor->aConf['homestatic']]['active']) {
-					$menu = str_replace('#static_id','page-blog',$format);
-					if ($this->plxMotor->get AND preg_match('/^(blog|categorie|archives|tag|article)/', $_SERVER['QUERY_STRING'])) {
+					$menu = str_replace('#static_id','static-blog',$format);
+					if ($this->plxMotor->get AND preg_match('/(blog|categorie|archives|tag|article)/', $_SERVER['QUERY_STRING'].$this->plxMotor->mode)) {
 						$menu = str_replace('#static_status','active',$menu);
 					} else {
 						$menu = str_replace('#static_status','noactive',$menu);
 					}
 					$menu = str_replace('#static_url', $this->plxMotor->urlRewrite('?blog'),$menu);
 					$menu = str_replace('#static_name',L_PAGEBLOG_TITLE,$menu);
-					$menu = str_replace('#static_class','',$menu);
+					$menu = str_replace('#static_class','static menu',$menu);
 					array_splice($menus, (intval($menublog)-1), 0, array($menu));
 				}
 			}
@@ -1335,6 +1346,7 @@ class plxShow {
 				else {
 					$group = str_replace('#group_id','static-group-'.plxUtils::title2url($k),$format_group);
 					$group = str_replace('#group_class','static group',$group);
+					$group = str_replace('#group_status',($group_active==$k?'active':'noactive'),$group);
 					$group = str_replace('#group_name',plxUtils::strCheck($k),$group);
 					echo "\n<li>\n\t".$group."\n\t<ul id=\"static-".plxUtils::title2url($k)."\">\t\t";
 					foreach($v as $kk => $vv) {
@@ -1365,20 +1377,26 @@ class plxShow {
 	}
 
 	/**
-	 * Méthode qui affiche l'url de la page statique de type relatif ou absolu
+	 * Méthode qui affiche ou retourne l'url de la page statique
 	 *
-	 * @param	type	type de lien : relatif ou absolu (URL complète)
+	 * @param	echo 	si à VRAI affichage à l'écran
+	 * @param 	extra 	paramètres supplémentaires pouvant être rajoutés à la fin de l'url de l'atricle
 	 * @return	stdout
 	 * @scope	static
 	 * @author	Florent MONTHEL, Stéphane F
 	 **/
-	public function staticUrl($type='relatif') {
+	public function staticUrl($echo=true, $extra='') {
 
 		# Recupération ID URL
 		$staticId = $this->staticId();
 		$staticIdFill = str_pad($staticId,3,'0',STR_PAD_LEFT);
-		if(!empty($staticId) AND isset($this->plxMotor->aStats[ $staticIdFill ]))
-			echo $this->plxMotor->urlRewrite('?static'.$staticId.'/'.$this->plxMotor->aStats[ $staticIdFill ]['url']);
+		if(!empty($staticId) AND isset($this->plxMotor->aStats[$staticIdFill])) {
+			$url = $this->plxMotor->urlRewrite('?static'.$staticId.'/'.$this->plxMotor->aStats[$staticIdFill]['url'].$extra);
+			if($echo)
+				echo $url;
+			else
+				return $url;
+		}
 	}
 
 	/**
@@ -1677,8 +1695,7 @@ class plxShow {
 					}
 				}
 			}
-			# limite sur le nombre de tags à afficher
-			if($max!='') $array=array_slice($array, 0, intval($max), true);
+
 			# tri des tags
 			switch($order) {
 				case 'alpha':
@@ -1694,7 +1711,24 @@ class plxShow {
 					$array = $arr_elem;
 					break;
 			}
+
+			# limite sur le nombre de tags à afficher
+			if($max!='') $array=array_slice($array, 0, intval($max), true);
+
 		}
+
+		$mode = $this->plxMotor->mode;
+
+		# Récupération de la liste des tags de l'article si on est en mode 'article'
+		# pour mettre en évidence les tags dans la sidebar s'ils sont attachés à l'article
+		$artTags = array();
+		if($mode=='article') {
+			$artTagList = $this->plxMotor->plxRecord_arts->f('tags');
+			if(!empty($artTagList)) {
+				$artTags = array_map('trim', explode(',', $artTagList));
+			}
+		}
+
 		# On affiche la liste
 		$size=0;
 		foreach($array as $tagname => $tag) {
@@ -1705,7 +1739,11 @@ class plxShow {
 			$name = str_replace('#tag_url',$this->plxMotor->urlRewrite('?tag/'.$tag['url']),$name);
 			$name = str_replace('#tag_name',plxUtils::strCheck($tag['name']),$name);
 			$name = str_replace('#nb_art',$tag['count'],$name);
-			$name = str_replace('#tag_status',(($this->plxMotor->mode=='tags' AND $this->plxMotor->cible==$tag['url'])?'active':'noactive'), $name);
+			if($mode=='article' AND in_array($tag['name'],$artTags))
+				$name = str_replace('#tag_status','active', $name);
+			else
+				$name = str_replace('#tag_status',(($mode=='tags' AND $this->plxMotor->cible==$tag['url'])?'active':'noactive'), $name);
+
 			echo $name;
 		}
 	}
@@ -1776,18 +1814,19 @@ class plxShow {
 	 * @scope	global
 	 * @author	Stephane F
 	 **/
-	public function pageBlog($format='<li id="#page_id"><a class="#page_status" href="#page_url" title="#page_name">#page_name</a></li>') {
+	public function pageBlog($format='<li class="#page_class #page_status" id="#page_id"><a href="#page_url" title="#page_name">#page_name</a></li>') {
 		# Hook Plugins
 		if(eval($this->plxMotor->plxPlugins->callHook('plxShowPageBlog'))) return;
 
 		if($this->plxMotor->aConf['homestatic']!='' AND isset($this->plxMotor->aStats[$this->plxMotor->aConf['homestatic']])) {
 			if($this->plxMotor->aStats[$this->plxMotor->aConf['homestatic']]['active']) {
-				$name = str_replace('#page_id','page-blog',$format);
-				if ($this->plxMotor->get AND preg_match('/^(blog|categorie|archives|tag|article)/', $_SERVER['QUERY_STRING'])) {
+				$name = str_replace('#page_id','static-blog',$format);
+				if ($this->plxMotor->get AND preg_match('/(blog|categorie|archives|tag|article)/', $_SERVER['QUERY_STRING'].$this->plxMotor->mode)) {
 					$name = str_replace('#page_status','active',$name);
 				} else {
 					$name = str_replace('#page_status','noactive',$name);
 				}
+				$name = str_replace('#page_class','static menu',$name);
 				$name = str_replace('#page_url', $this->plxMotor->urlRewrite('?blog'),$name);
 				$name = str_replace('#page_name',L_PAGEBLOG_TITLE,$name);
 				echo $name;
@@ -1808,9 +1847,15 @@ class plxShow {
 		if(eval($this->plxMotor->plxPlugins->callHook('plxShowTemplateCss'))) return;
 
 		$theme = $this->plxMotor->aConf['racine_themes'].$this->plxMotor->style.'/';
+		$min_css = str_replace('php','min.css',$this->plxMotor->template);
 		$css = str_replace('php','css',$this->plxMotor->template);
-		if(is_file($theme.$css_dir.$css))
+
+		if(is_file($theme.$css_dir.$min_css)) {
+			echo '<link rel="stylesheet" type="text/css" href="'.$this->plxMotor->urlRewrite($theme.$css_dir.$min_css).'" media="screen" />'."\n";
+		}
+		elseif(is_file($theme.$css_dir.$css)) {
 			echo '<link rel="stylesheet" type="text/css" href="'.$this->plxMotor->urlRewrite($theme.$css_dir.$css).'" media="screen" />'."\n";
+		}
 	}
 
 	/**
@@ -1902,4 +1947,4 @@ class plxShow {
 	}
 
 }
-?>
\ No newline at end of file
+?>
