@@ -46,6 +46,11 @@ $LANG = array(
 'SEND'					=> 'Invia',
 'COMMENTS_CLOSED'		=> 'Commenti bloccati',
 'ANTISPAM_WARNING'		=> 'Verifica antispam',
+
+'REPLY'					=> 'Rispondere',
+'REPLY_TO'				=> 'Rispondere',
+'CANCEL'				=> 'Annullare',
+
 );
 
 ?>
